@@ -3,13 +3,13 @@
 /// See [docs/md013.md](../../docs/md013.md) for full documentation, configuration, and examples.
 use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rule_config_serde::RuleConfig;
-use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
 use crate::utils::range_utils::LineIndex;
 use crate::utils::range_utils::calculate_excess_range;
 use crate::utils::regex_cache::{
     IMAGE_REF_PATTERN, INLINE_LINK_REGEX as MARKDOWN_LINK_PATTERN, LINK_REF_PATTERN, URL_IN_TEXT, URL_PATTERN,
 };
 use crate::utils::table_utils::TableUtils;
+use crate::utils::text_reflow::split_into_sentences;
 use toml;
 
 pub mod md013_config;
@@ -44,7 +44,7 @@ impl MD013LineLength {
         line: &str,
         _lines: &[&str],
         current_line: usize,
-        structure: &DocumentStructure,
+        ctx: &crate::lint_context::LintContext,
     ) -> bool {
         if self.config.strict {
             return false;
@@ -69,10 +69,7 @@ impl MD013LineLength {
         }
 
         // Code blocks with long strings (only check if in code block)
-        if structure.is_in_code_block(current_line + 1)
-            && !trimmed.is_empty()
-            && !line.contains(' ')
-            && !line.contains('\t')
+        if ctx.is_in_code_block(current_line + 1) && !trimmed.is_empty() && !line.contains(' ') && !line.contains('\t')
         {
             return true;
         }
@@ -94,26 +91,18 @@ impl Rule for MD013LineLength {
         let content = ctx.content;
 
         // Fast early return using should_skip
-        if self.should_skip(ctx) && !(self.config.reflow && self.config.reflow_mode == ReflowMode::Normalize) {
+        // But don't skip if we're in reflow mode with Normalize or SentencePerLine
+        if self.should_skip(ctx)
+            && !(self.config.reflow
+                && (self.config.reflow_mode == ReflowMode::Normalize
+                    || self.config.reflow_mode == ReflowMode::SentencePerLine))
+        {
             return Ok(Vec::new());
         }
 
-        // Create structure manually
-        let structure = DocumentStructure::new(content);
-        self.check_with_structure(ctx, &structure)
-    }
-
-    /// Optimized check using pre-computed document structure
-    fn check_with_structure(
-        &self,
-        ctx: &crate::lint_context::LintContext,
-        structure: &DocumentStructure,
-    ) -> LintResult {
-        let content = ctx.content;
+        // Direct implementation without DocumentStructure
         let mut warnings = Vec::new();
 
-        // Early return was already done in check(), so we know there are long lines
-
         // Check for inline configuration overrides
         let inline_config = crate::inline_config::InlineConfig::from_content(content);
         let config_override = inline_config.get_rule_config("MD013");
@@ -144,6 +133,7 @@ impl Rule for MD013LineLength {
                     config.reflow_mode = match reflow_mode {
                         "default" => ReflowMode::Default,
                         "normalize" => ReflowMode::Normalize,
+                        "sentence-per-line" => ReflowMode::SentencePerLine,
                         _ => ReflowMode::default(),
                     };
                 }
@@ -164,9 +154,11 @@ impl Rule for MD013LineLength {
             }
         }
 
-        // If no candidate lines and not in normalize mode, early return
+        // If no candidate lines and not in normalize or sentence-per-line mode, early return
         if candidate_lines.is_empty()
-            && !(effective_config.reflow && effective_config.reflow_mode == ReflowMode::Normalize)
+            && !(effective_config.reflow
+                && (effective_config.reflow_mode == ReflowMode::Normalize
+                    || effective_config.reflow_mode == ReflowMode::SentencePerLine))
         {
             return Ok(warnings);
         }
@@ -180,7 +172,12 @@ impl Rule for MD013LineLength {
 
         // Create a quick lookup set for heading lines (only if needed)
         let heading_lines_set: std::collections::HashSet<usize> = if !effective_config.headings {
-            structure.heading_lines.iter().cloned().collect()
+            ctx.lines
+                .iter()
+                .enumerate()
+                .filter(|(_, line)| line.heading.is_some())
+                .map(|(idx, _)| idx + 1)
+                .collect()
         } else {
             std::collections::HashSet::new()
         };
@@ -202,70 +199,73 @@ impl Rule for MD013LineLength {
         };
 
         // Only process candidate lines that were pre-filtered
-        for &line_idx in &candidate_lines {
-            let line_number = line_idx + 1;
-            let line = lines[line_idx];
+        // Skip line length checks entirely in sentence-per-line mode
+        if effective_config.reflow_mode != ReflowMode::SentencePerLine {
+            for &line_idx in &candidate_lines {
+                let line_number = line_idx + 1;
+                let line = lines[line_idx];
 
-            // Calculate effective length excluding unbreakable URLs
-            let effective_length = self.calculate_effective_length(line);
+                // Calculate effective length excluding unbreakable URLs
+                let effective_length = self.calculate_effective_length(line);
 
-            // Use single line length limit for all content
-            let line_limit = effective_config.line_length;
+                // Use single line length limit for all content
+                let line_limit = effective_config.line_length;
 
-            // Skip short lines immediately (double-check after effective length calculation)
-            if effective_length <= line_limit {
-                continue;
+                // Skip short lines immediately (double-check after effective length calculation)
+                if effective_length <= line_limit {
+                    continue;
+                }
+
+                // Skip various block types efficiently
+                if !effective_config.strict {
+                    // Skip setext heading underlines
+                    if !line.trim().is_empty() && line.trim().chars().all(|c| c == '=' || c == '-') {
+                        continue;
+                    }
+
+                    // Skip block elements according to config flags
+                    // The flags mean: true = check these elements, false = skip these elements
+                    // So we skip when the flag is FALSE and the line is in that element type
+                    if (!effective_config.headings && heading_lines_set.contains(&line_number))
+                        || (!effective_config.code_blocks && ctx.is_in_code_block(line_number))
+                        || (!effective_config.tables && table_lines_set.contains(&line_number))
+                        || ctx.lines[line_number - 1].blockquote.is_some()
+                        || ctx.is_in_html_block(line_number)
+                    {
+                        continue;
+                    }
+
+                    // Skip lines that are only a URL, image ref, or link ref
+                    if self.should_ignore_line(line, &lines, line_idx, ctx) {
+                        continue;
+                    }
+                }
+
+                // Don't provide fix for individual lines when reflow is enabled
+                // Paragraph-based fixes will be handled separately
+                let fix = None;
+
+                let message = format!("Line length {effective_length} exceeds {line_limit} characters");
+
+                // Calculate precise character range for the excess portion
+                let (start_line, start_col, end_line, end_col) = calculate_excess_range(line_number, line, line_limit);
+
+                warnings.push(LintWarning {
+                    rule_name: Some(self.name()),
+                    message,
+                    line: start_line,
+                    column: start_col,
+                    end_line,
+                    end_column: end_col,
+                    severity: Severity::Warning,
+                    fix,
+                });
             }
-
-            // Skip various block types efficiently
-            if !effective_config.strict {
-                // Skip setext heading underlines
-                if !line.trim().is_empty() && line.trim().chars().all(|c| c == '=' || c == '-') {
-                    continue;
-                }
-
-                // Skip block elements according to config flags
-                // The flags mean: true = check these elements, false = skip these elements
-                // So we skip when the flag is FALSE and the line is in that element type
-                if (!effective_config.headings && heading_lines_set.contains(&line_number))
-                    || (!effective_config.code_blocks && structure.is_in_code_block(line_number))
-                    || (!effective_config.tables && table_lines_set.contains(&line_number))
-                    || structure.is_in_blockquote(line_number)
-                    || structure.is_in_html_block(line_number)
-                {
-                    continue;
-                }
-
-                // Skip lines that are only a URL, image ref, or link ref
-                if self.should_ignore_line(line, &lines, line_idx, structure) {
-                    continue;
-                }
-            }
-
-            // Don't provide fix for individual lines when reflow is enabled
-            // Paragraph-based fixes will be handled separately
-            let fix = None;
-
-            let message = format!("Line length {effective_length} exceeds {line_limit} characters");
-
-            // Calculate precise character range for the excess portion
-            let (start_line, start_col, end_line, end_col) = calculate_excess_range(line_number, line, line_limit);
-
-            warnings.push(LintWarning {
-                rule_name: Some(self.name()),
-                message,
-                line: start_line,
-                column: start_col,
-                end_line,
-                end_column: end_col,
-                severity: Severity::Warning,
-                fix,
-            });
         }
 
         // If reflow is enabled, generate paragraph-based fixes
         if effective_config.reflow {
-            let paragraph_warnings = self.generate_paragraph_fixes(ctx, structure, &effective_config, &lines);
+            let paragraph_warnings = self.generate_paragraph_fixes(ctx, &effective_config, &lines);
             // Merge paragraph warnings with line warnings, removing duplicates
             for pw in paragraph_warnings {
                 // Remove any line warnings that overlap with this paragraph
@@ -296,10 +296,6 @@ impl Rule for MD013LineLength {
         self
     }
 
-    fn as_maybe_document_structure(&self) -> Option<&dyn crate::rule::MaybeDocumentStructure> {
-        Some(self)
-    }
-
     fn category(&self) -> RuleCategory {
         RuleCategory::Whitespace
     }
@@ -310,6 +306,14 @@ impl Rule for MD013LineLength {
             return true;
         }
 
+        // For sentence-per-line or normalize mode, never skip based on line length
+        if self.config.reflow
+            && (self.config.reflow_mode == ReflowMode::SentencePerLine
+                || self.config.reflow_mode == ReflowMode::Normalize)
+        {
+            return false;
+        }
+
         // Quick check: if total content is shorter than line limit, definitely skip
         if ctx.content.len() <= self.config.line_length {
             return true;
@@ -362,7 +366,6 @@ impl MD013LineLength {
     fn generate_paragraph_fixes(
         &self,
         ctx: &crate::lint_context::LintContext,
-        structure: &DocumentStructure,
         config: &MD013Config,
         lines: &[&str],
     ) -> Vec<LintWarning> {
@@ -374,9 +377,10 @@ impl MD013LineLength {
             let line_num = i + 1;
 
             // Skip special structures
-            if structure.is_in_code_block(line_num)
-                || structure.is_in_html_block(line_num)
-                || structure.is_in_blockquote(line_num)
+            if ctx.is_in_code_block(line_num)
+                || ctx.is_in_front_matter(line_num)
+                || ctx.is_in_html_block(line_num)
+                || (line_num > 0 && line_num <= ctx.lines.len() && ctx.lines[line_num - 1].blockquote.is_some())
                 || lines[i].trim().starts_with('#')
                 || TableUtils::is_potential_table_row(lines[i])
                 || lines[i].trim().is_empty()
@@ -427,12 +431,21 @@ impl MD013LineLength {
                     }
                 }
 
+                // Check if any lines in this list item are within a code block
+                let contains_code_block = (list_start..i).any(|line_idx| ctx.is_in_code_block(line_idx + 1));
+
                 // Now check if this list item needs reflowing
                 let combined_content = list_item_lines.join(" ").trim().to_string();
                 let full_line = format!("{marker}{combined_content}");
 
-                if self.calculate_effective_length(&full_line) > config.line_length
-                    || (config.reflow_mode == ReflowMode::Normalize && list_item_lines.len() > 1)
+                if !contains_code_block
+                    && (self.calculate_effective_length(&full_line) > config.line_length
+                        || (config.reflow_mode == ReflowMode::Normalize && list_item_lines.len() > 1)
+                        || (config.reflow_mode == ReflowMode::SentencePerLine && {
+                            // Check if list item has multiple sentences
+                            let sentences = split_into_sentences(&combined_content);
+                            sentences.len() > 1
+                        }))
                 {
                     let start_range = line_index.whole_line_range(list_start + 1);
                     let end_line = i - 1;
@@ -448,6 +461,7 @@ impl MD013LineLength {
                         line_length: config.line_length - indent_size,
                         break_on_sentences: true,
                         preserve_breaks: false,
+                        sentence_per_line: config.reflow_mode == ReflowMode::SentencePerLine,
                     };
                     let reflowed = crate::utils::text_reflow::reflow_line(&combined_content, &reflow_options);
 
@@ -467,10 +481,14 @@ impl MD013LineLength {
 
                     warnings.push(LintWarning {
                         rule_name: Some(self.name()),
-                        message: format!(
-                            "Line length exceeds {} characters and can be reflowed",
-                            config.line_length
-                        ),
+                        message: if config.reflow_mode == ReflowMode::SentencePerLine {
+                            "Line contains multiple sentences (one sentence per line expected)".to_string()
+                        } else {
+                            format!(
+                                "Line length exceeds {} characters and can be reflowed",
+                                config.line_length
+                            )
+                        },
                         line: list_start + 1,
                         column: 1,
                         end_line: end_line + 1,
@@ -497,9 +515,12 @@ impl MD013LineLength {
 
                 // Stop at paragraph boundaries
                 if next_trimmed.is_empty()
-                    || structure.is_in_code_block(next_line_num)
-                    || structure.is_in_html_block(next_line_num)
-                    || structure.is_in_blockquote(next_line_num)
+                    || ctx.is_in_code_block(next_line_num)
+                    || ctx.is_in_front_matter(next_line_num)
+                    || ctx.is_in_html_block(next_line_num)
+                    || (next_line_num > 0
+                        && next_line_num <= ctx.lines.len()
+                        && ctx.lines[next_line_num - 1].blockquote.is_some())
                     || next_trimmed.starts_with('#')
                     || TableUtils::is_potential_table_row(next_line)
                     || is_list_item(next_trimmed)
@@ -520,14 +541,25 @@ impl MD013LineLength {
             }
 
             // Check if this paragraph needs reflowing
-            let needs_reflow = if config.reflow_mode == ReflowMode::Normalize {
-                // In normalize mode, reflow multi-line paragraphs
-                paragraph_lines.len() > 1
-            } else {
-                // In default mode, only reflow if lines exceed limit
-                paragraph_lines
-                    .iter()
-                    .any(|line| self.calculate_effective_length(line) > config.line_length)
+            let needs_reflow = match config.reflow_mode {
+                ReflowMode::Normalize => {
+                    // In normalize mode, reflow multi-line paragraphs
+                    paragraph_lines.len() > 1
+                }
+                ReflowMode::SentencePerLine => {
+                    // In sentence-per-line mode, check if any line has multiple sentences
+                    paragraph_lines.iter().any(|line| {
+                        // Count sentences in this line
+                        let sentences = split_into_sentences(line);
+                        sentences.len() > 1
+                    })
+                }
+                ReflowMode::Default => {
+                    // In default mode, only reflow if lines exceed limit
+                    paragraph_lines
+                        .iter()
+                        .any(|line| self.calculate_effective_length(line) > config.line_length)
+                }
             };
 
             if needs_reflow {
@@ -558,6 +590,7 @@ impl MD013LineLength {
                     line_length: config.line_length,
                     break_on_sentences: true,
                     preserve_breaks: false,
+                    sentence_per_line: config.reflow_mode == ReflowMode::SentencePerLine,
                 };
                 let mut reflowed = crate::utils::text_reflow::reflow_line(&paragraph_text, &reflow_options);
 
@@ -581,32 +614,48 @@ impl MD013LineLength {
                 // Create warning with actual fix
                 // In default mode, report the specific line that violates
                 // In normalize mode, report the whole paragraph
-                let (warning_line, warning_end_line) = if config.reflow_mode == ReflowMode::Normalize {
-                    (paragraph_start + 1, end_line + 1)
-                } else {
-                    // Find the first line that exceeds the limit
-                    let mut violating_line = paragraph_start;
-                    for (idx, line) in paragraph_lines.iter().enumerate() {
-                        if self.calculate_effective_length(line) > config.line_length {
-                            violating_line = paragraph_start + idx;
-                            break;
+                // In sentence-per-line mode, report lines with multiple sentences
+                let (warning_line, warning_end_line) = match config.reflow_mode {
+                    ReflowMode::Normalize => (paragraph_start + 1, end_line + 1),
+                    ReflowMode::SentencePerLine => {
+                        // Find the first line with multiple sentences
+                        let mut violating_line = paragraph_start;
+                        for (idx, line) in paragraph_lines.iter().enumerate() {
+                            let sentences = split_into_sentences(line);
+                            if sentences.len() > 1 {
+                                violating_line = paragraph_start + idx;
+                                break;
+                            }
                         }
+                        (violating_line + 1, violating_line + 1)
+                    }
+                    ReflowMode::Default => {
+                        // Find the first line that exceeds the limit
+                        let mut violating_line = paragraph_start;
+                        for (idx, line) in paragraph_lines.iter().enumerate() {
+                            if self.calculate_effective_length(line) > config.line_length {
+                                violating_line = paragraph_start + idx;
+                                break;
+                            }
+                        }
+                        (violating_line + 1, violating_line + 1)
                     }
-                    (violating_line + 1, violating_line + 1)
                 };
 
                 warnings.push(LintWarning {
                     rule_name: Some(self.name()),
-                    message: if config.reflow_mode == ReflowMode::Normalize {
-                        format!(
+                    message: match config.reflow_mode {
+                        ReflowMode::Normalize => format!(
                             "Paragraph could be normalized to use line length of {} characters",
                             config.line_length
-                        )
-                    } else {
-                        format!(
+                        ),
+                        ReflowMode::SentencePerLine => {
+                            "Line contains multiple sentences (one sentence per line expected)".to_string()
+                        }
+                        ReflowMode::Default => format!(
                             "Line length exceeds {} characters and can be reflowed",
                             config.line_length
-                        )
+                        ),
                     },
                     line: warning_line,
                     column: 1,
@@ -676,17 +725,6 @@ impl MD013LineLength {
     }
 }
 
-impl DocumentStructureExtensions for MD013LineLength {
-    fn has_relevant_elements(
-        &self,
-        ctx: &crate::lint_context::LintContext,
-        _doc_structure: &DocumentStructure,
-    ) -> bool {
-        // This rule always applies unless content is empty
-        !ctx.content.is_empty()
-    }
-}
-
 /// Extract list marker and content from a list item
 fn extract_list_marker_and_content(line: &str) -> (String, String) {
     // First, find the leading indentation
@@ -1123,15 +1161,16 @@ Another long line that should trigger a warning."#;
     }
 
     #[test]
-    fn test_has_relevant_elements() {
+    fn test_content_detection() {
         let rule = MD013LineLength::default();
-        let structure = DocumentStructure::new("test");
 
-        let ctx = LintContext::new("Some content", crate::config::MarkdownFlavor::Standard);
-        assert!(rule.has_relevant_elements(&ctx, &structure));
+        // Use a line longer than default line_length (80) to ensure it's not skipped
+        let long_line = "a".repeat(100);
+        let ctx = LintContext::new(&long_line, crate::config::MarkdownFlavor::Standard);
+        assert!(!rule.should_skip(&ctx)); // Should not skip processing when there's long content
 
         let empty_ctx = LintContext::new("", crate::config::MarkdownFlavor::Standard);
-        assert!(!rule.has_relevant_elements(&empty_ctx, &structure));
+        assert!(rule.should_skip(&empty_ctx)); // Should skip processing when content is empty
     }
 
     #[test]
@@ -2247,4 +2286,128 @@ with multiple lines."#;
             "Paragraph should be normalized"
         );
     }
+
+    #[test]
+    fn test_sentence_per_line_detection() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config.clone());
+
+        // Test detection of multiple sentences
+        let content = "This is sentence one. This is sentence two. And sentence three!";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+
+        // Debug: check if should_skip returns false
+        assert!(!rule.should_skip(&ctx), "Should not skip for sentence-per-line mode");
+
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(!result.is_empty(), "Should detect multiple sentences on one line");
+        assert_eq!(
+            result[0].message,
+            "Line contains multiple sentences (one sentence per line expected)"
+        );
+    }
+
+    #[test]
+    fn test_sentence_per_line_fix() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "First sentence. Second sentence.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(!result.is_empty(), "Should detect violation");
+        assert!(result[0].fix.is_some(), "Should provide a fix");
+
+        let fix = result[0].fix.as_ref().unwrap();
+        assert_eq!(fix.replacement.trim(), "First sentence.\nSecond sentence.");
+    }
+
+    #[test]
+    fn test_sentence_per_line_abbreviations() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        // Should NOT trigger on abbreviations
+        let content = "Mr. Smith met Dr. Jones at 3:00 PM.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Should not detect abbreviations as sentence boundaries"
+        );
+    }
+
+    #[test]
+    fn test_sentence_per_line_with_markdown() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "# Heading\n\nSentence with **bold**. Another with [link](url).";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(!result.is_empty(), "Should detect multiple sentences with markdown");
+        assert_eq!(result[0].line, 3); // Third line has the violation
+    }
+
+    #[test]
+    fn test_sentence_per_line_questions_exclamations() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "Is this a question? Yes it is! And a statement.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(!result.is_empty(), "Should detect sentences with ? and !");
+
+        let fix = result[0].fix.as_ref().unwrap();
+        let lines: Vec<&str> = fix.replacement.trim().lines().collect();
+        assert_eq!(lines.len(), 3);
+        assert_eq!(lines[0], "Is this a question?");
+        assert_eq!(lines[1], "Yes it is!");
+        assert_eq!(lines[2], "And a statement.");
+    }
+
+    #[test]
+    fn test_sentence_per_line_in_lists() {
+        let config = MD013Config {
+            reflow: true,
+            reflow_mode: ReflowMode::SentencePerLine,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "- List item one. With two sentences.\n- Another item.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(!result.is_empty(), "Should detect sentences in list items");
+        // The fix should preserve list formatting
+        let fix = result[0].fix.as_ref().unwrap();
+        assert!(fix.replacement.starts_with("- "), "Should preserve list marker");
+    }
 }
