@@ -523,10 +523,6 @@ impl Rule for MD022BlanksAroundHeadings {
         self
     }
 
-    fn as_maybe_document_structure(&self) -> Option<&dyn crate::rule::MaybeDocumentStructure> {
-        None
-    }
-
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
         let default_config = MD022Config::default();
         let json_value = serde_json::to_value(&default_config).ok()?;
