@@ -480,10 +480,6 @@ impl Rule for MD025SingleTitle {
         self
     }
 
-    fn as_maybe_document_structure(&self) -> Option<&dyn crate::rule::MaybeDocumentStructure> {
-        None
-    }
-
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
         let json_value = serde_json::to_value(&self.config).ok()?;
         Some((
