@@ -99,20 +99,203 @@ impl MD034NoBareUrls {
         &url[..end]
     }
 
-    // Uses DocumentStructure for code block and code span detection in check_with_structure.
-    pub fn check_with_structure(
+    /// AST-based bare URL detection: only flag URLs in text nodes not inside links/images/code/html
+    fn find_bare_urls_in_ast(
         &self,
-        ctx: &crate::lint_context::LintContext,
-        _structure: &crate::utils::document_structure::DocumentStructure,
-    ) -> LintResult {
+        node: &Node,
+        parent_is_link_or_image: bool,
+        _content: &str,
+        warnings: &mut Vec<LintWarning>,
+        ctx: &LintContext,
+    ) {
+        use markdown::mdast::Node::*;
+        match node {
+            Text(text) if !parent_is_link_or_image => {
+                let text_str = &text.value;
+
+                // Check for URLs
+                for url_match in SIMPLE_URL_REGEX.find_iter(text_str) {
+                    let url_start = url_match.start();
+                    let mut url_end = url_match.end();
+
+                    // Trim trailing punctuation that's likely sentence punctuation
+                    let raw_url = &text_str[url_start..url_end];
+                    let trimmed_url = self.trim_trailing_punctuation(raw_url);
+                    url_end = url_start + trimmed_url.len();
+
+                    // Skip if URL became empty after trimming
+                    if url_end <= url_start {
+                        continue;
+                    }
+
+                    let before = if url_start == 0 {
+                        None
+                    } else {
+                        text_str.get(url_start - 1..url_start)
+                    };
+                    let after = text_str.get(url_end..url_end + 1);
+                    let is_valid_boundary = before
+                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
+                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_");
+                    if !is_valid_boundary {
+                        continue;
+                    }
+                    if let Some(pos) = &text.position {
+                        let offset = pos.start.offset + url_start;
+                        let (line, column) = ctx.offset_to_line_col(offset);
+                        let url_text = &text_str[url_start..url_end];
+                        let (start_line, start_col, end_line, end_col) =
+                            (line, column, line, column + url_text.chars().count());
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            line: start_line,
+                            column: start_col,
+                            end_line,
+                            end_column: end_col,
+                            message: "URL without angle brackets or link formatting".to_string(),
+                            severity: Severity::Warning,
+                            fix: Some(Fix {
+                                range: offset..(offset + url_text.len()),
+                                replacement: format!("<{url_text}>"),
+                            }),
+                        });
+                    }
+                }
+
+                // Check for email addresses
+                for email_match in EMAIL_PATTERN.find_iter(text_str) {
+                    let email_start = email_match.start();
+                    let email_end = email_match.end();
+                    let before = if email_start == 0 {
+                        None
+                    } else {
+                        text_str.get(email_start - 1..email_start)
+                    };
+                    let after = text_str.get(email_end..email_end + 1);
+                    let is_valid_boundary = before
+                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
+                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".");
+                    if !is_valid_boundary {
+                        continue;
+                    }
+                    if let Some(pos) = &text.position {
+                        let offset = pos.start.offset + email_start;
+                        let (line, column) = ctx.offset_to_line_col(offset);
+                        let email_text = &text_str[email_start..email_end];
+                        let (start_line, start_col, end_line, end_col) =
+                            (line, column, line, column + email_text.chars().count());
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            line: start_line,
+                            column: start_col,
+                            end_line,
+                            end_column: end_col,
+                            message: "Email address without angle brackets or link formatting (wrap like: <email>)"
+                                .to_string(),
+                            severity: Severity::Warning,
+                            fix: Some(Fix {
+                                range: offset..(offset + email_text.len()),
+                                replacement: format!("<{email_text}>"),
+                            }),
+                        });
+                    }
+                }
+            }
+            Link(link) => {
+                for child in &link.children {
+                    self.find_bare_urls_in_ast(child, true, _content, warnings, ctx);
+                }
+            }
+            Image(image) => {
+                // Only check alt text for bare URLs (rare, but possible)
+                let alt_str = &image.alt;
+                for url_match in SIMPLE_URL_REGEX.find_iter(alt_str) {
+                    let url_start = url_match.start();
+                    let mut url_end = url_match.end();
+
+                    // Trim trailing punctuation that's likely sentence punctuation
+                    let raw_url = &alt_str[url_start..url_end];
+                    let trimmed_url = self.trim_trailing_punctuation(raw_url);
+                    url_end = url_start + trimmed_url.len();
+
+                    // Skip if URL became empty after trimming
+                    if url_end <= url_start {
+                        continue;
+                    }
+
+                    let before = if url_start == 0 {
+                        None
+                    } else {
+                        alt_str.get(url_start - 1..url_start)
+                    };
+                    let after = alt_str.get(url_end..url_end + 1);
+                    let is_valid_boundary = before
+                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
+                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_");
+                    if !is_valid_boundary {
+                        continue;
+                    }
+                    if let Some(pos) = &image.position {
+                        let offset = pos.start.offset + url_start;
+                        let (line, column) = ctx.offset_to_line_col(offset);
+                        let url_text = &alt_str[url_start..url_end];
+                        let (start_line, start_col, end_line, end_col) =
+                            (line, column, line, column + url_text.chars().count());
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            line: start_line,
+                            column: start_col,
+                            end_line,
+                            end_column: end_col,
+                            message: "URL without angle brackets or link formatting".to_string(),
+                            severity: Severity::Warning,
+                            fix: Some(Fix {
+                                range: offset..(offset + url_text.len()),
+                                replacement: format!("<{url_text}>"),
+                            }),
+                        });
+                    }
+                }
+            }
+            Code(_) | InlineCode(_) | Html(_) => {
+                // Skip code and HTML nodes
+            }
+            _ => {
+                if let Some(children) = node.children() {
+                    for child in children {
+                        self.find_bare_urls_in_ast(child, false, _content, warnings, ctx);
+                    }
+                }
+            }
+        }
+    }
+
+    /// AST-based check method for MD034
+    pub fn check_ast(&self, ctx: &LintContext, ast: &Node) -> LintResult {
+        let mut warnings = Vec::new();
+        self.find_bare_urls_in_ast(ast, false, ctx.content, &mut warnings, ctx);
+        Ok(warnings)
+    }
+}
+
+impl Rule for MD034NoBareUrls {
+    fn name(&self) -> &'static str {
+        "MD034"
+    }
+
+    fn description(&self) -> &'static str {
+        "URL without angle brackets or link formatting"
+    }
+
+    fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
+        // Use line-based detection to properly distinguish between bare URLs and autolinks
+        // AST-based approach doesn't work because CommonMark parser converts bare URLs to links
         let content = ctx.content;
 
-        // Early return: skip if no URLs or emails
-        if self.should_skip(content) {
-            return Ok(vec![]);
+        // Fast path: Early return for empty content
+        if content.is_empty() || self.should_skip(content) {
+            return Ok(Vec::new());
         }
-
-        // Process the entire content to handle multi-line markdown links
         let mut warnings = Vec::new();
 
         // First, find all markdown link ranges across the entire content
@@ -355,209 +538,6 @@ impl MD034NoBareUrls {
         Ok(warnings)
     }
 
-    /// AST-based bare URL detection: only flag URLs in text nodes not inside links/images/code/html
-    fn find_bare_urls_in_ast(
-        &self,
-        node: &Node,
-        parent_is_link_or_image: bool,
-        _content: &str,
-        warnings: &mut Vec<LintWarning>,
-        ctx: &LintContext,
-    ) {
-        use markdown::mdast::Node::*;
-        match node {
-            Text(text) if !parent_is_link_or_image => {
-                let text_str = &text.value;
-
-                // Check for URLs
-                for url_match in SIMPLE_URL_REGEX.find_iter(text_str) {
-                    let url_start = url_match.start();
-                    let mut url_end = url_match.end();
-
-                    // Trim trailing punctuation that's likely sentence punctuation
-                    let raw_url = &text_str[url_start..url_end];
-                    let trimmed_url = self.trim_trailing_punctuation(raw_url);
-                    url_end = url_start + trimmed_url.len();
-
-                    // Skip if URL became empty after trimming
-                    if url_end <= url_start {
-                        continue;
-                    }
-
-                    let before = if url_start == 0 {
-                        None
-                    } else {
-                        text_str.get(url_start - 1..url_start)
-                    };
-                    let after = text_str.get(url_end..url_end + 1);
-                    let is_valid_boundary = before
-                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
-                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_");
-                    if !is_valid_boundary {
-                        continue;
-                    }
-                    if let Some(pos) = &text.position {
-                        let offset = pos.start.offset + url_start;
-                        let (line, column) = ctx.offset_to_line_col(offset);
-                        let url_text = &text_str[url_start..url_end];
-                        let (start_line, start_col, end_line, end_col) =
-                            (line, column, line, column + url_text.chars().count());
-                        warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
-                            line: start_line,
-                            column: start_col,
-                            end_line,
-                            end_column: end_col,
-                            message: "URL without angle brackets or link formatting".to_string(),
-                            severity: Severity::Warning,
-                            fix: Some(Fix {
-                                range: offset..(offset + url_text.len()),
-                                replacement: format!("<{url_text}>"),
-                            }),
-                        });
-                    }
-                }
-
-                // Check for email addresses
-                for email_match in EMAIL_PATTERN.find_iter(text_str) {
-                    let email_start = email_match.start();
-                    let email_end = email_match.end();
-                    let before = if email_start == 0 {
-                        None
-                    } else {
-                        text_str.get(email_start - 1..email_start)
-                    };
-                    let after = text_str.get(email_end..email_end + 1);
-                    let is_valid_boundary = before
-                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
-                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".");
-                    if !is_valid_boundary {
-                        continue;
-                    }
-                    if let Some(pos) = &text.position {
-                        let offset = pos.start.offset + email_start;
-                        let (line, column) = ctx.offset_to_line_col(offset);
-                        let email_text = &text_str[email_start..email_end];
-                        let (start_line, start_col, end_line, end_col) =
-                            (line, column, line, column + email_text.chars().count());
-                        warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
-                            line: start_line,
-                            column: start_col,
-                            end_line,
-                            end_column: end_col,
-                            message: "Email address without angle brackets or link formatting (wrap like: <email>)"
-                                .to_string(),
-                            severity: Severity::Warning,
-                            fix: Some(Fix {
-                                range: offset..(offset + email_text.len()),
-                                replacement: format!("<{email_text}>"),
-                            }),
-                        });
-                    }
-                }
-            }
-            Link(link) => {
-                for child in &link.children {
-                    self.find_bare_urls_in_ast(child, true, _content, warnings, ctx);
-                }
-            }
-            Image(image) => {
-                // Only check alt text for bare URLs (rare, but possible)
-                let alt_str = &image.alt;
-                for url_match in SIMPLE_URL_REGEX.find_iter(alt_str) {
-                    let url_start = url_match.start();
-                    let mut url_end = url_match.end();
-
-                    // Trim trailing punctuation that's likely sentence punctuation
-                    let raw_url = &alt_str[url_start..url_end];
-                    let trimmed_url = self.trim_trailing_punctuation(raw_url);
-                    url_end = url_start + trimmed_url.len();
-
-                    // Skip if URL became empty after trimming
-                    if url_end <= url_start {
-                        continue;
-                    }
-
-                    let before = if url_start == 0 {
-                        None
-                    } else {
-                        alt_str.get(url_start - 1..url_start)
-                    };
-                    let after = alt_str.get(url_end..url_end + 1);
-                    let is_valid_boundary = before
-                        .is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
-                        && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_");
-                    if !is_valid_boundary {
-                        continue;
-                    }
-                    if let Some(pos) = &image.position {
-                        let offset = pos.start.offset + url_start;
-                        let (line, column) = ctx.offset_to_line_col(offset);
-                        let url_text = &alt_str[url_start..url_end];
-                        let (start_line, start_col, end_line, end_col) =
-                            (line, column, line, column + url_text.chars().count());
-                        warnings.push(LintWarning {
-                            rule_name: Some(self.name()),
-                            line: start_line,
-                            column: start_col,
-                            end_line,
-                            end_column: end_col,
-                            message: "URL without angle brackets or link formatting".to_string(),
-                            severity: Severity::Warning,
-                            fix: Some(Fix {
-                                range: offset..(offset + url_text.len()),
-                                replacement: format!("<{url_text}>"),
-                            }),
-                        });
-                    }
-                }
-            }
-            Code(_) | InlineCode(_) | Html(_) => {
-                // Skip code and HTML nodes
-            }
-            _ => {
-                if let Some(children) = node.children() {
-                    for child in children {
-                        self.find_bare_urls_in_ast(child, false, _content, warnings, ctx);
-                    }
-                }
-            }
-        }
-    }
-
-    /// AST-based check method for MD034
-    pub fn check_ast(&self, ctx: &LintContext, ast: &Node) -> LintResult {
-        let mut warnings = Vec::new();
-        self.find_bare_urls_in_ast(ast, false, ctx.content, &mut warnings, ctx);
-        Ok(warnings)
-    }
-}
-
-impl Rule for MD034NoBareUrls {
-    fn name(&self) -> &'static str {
-        "MD034"
-    }
-
-    fn description(&self) -> &'static str {
-        "URL without angle brackets or link formatting"
-    }
-
-    fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
-        // Use line-based detection to properly distinguish between bare URLs and autolinks
-        // AST-based approach doesn't work because CommonMark parser converts bare URLs to links
-        let content = ctx.content;
-
-        // Fast path: Early return for empty content
-        if content.is_empty() || self.should_skip(content) {
-            return Ok(Vec::new());
-        }
-
-        // Fallback path: create structure manually (should rarely be used)
-        let structure = crate::utils::document_structure::DocumentStructure::new(content);
-        self.check_with_structure(ctx, &structure)
-    }
-
     fn check_with_ast(&self, ctx: &LintContext, ast: &MarkdownAst) -> LintResult {
         // Use AST-based detection for better accuracy
         let mut warnings = Vec::new();
@@ -571,10 +551,6 @@ impl Rule for MD034NoBareUrls {
         false
     }
 
-    fn uses_document_structure(&self) -> bool {
-        true
-    }
-
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
         if self.should_skip(content) {
@@ -582,9 +558,7 @@ impl Rule for MD034NoBareUrls {
         }
 
         // Get all warnings first - only fix URLs that are actually flagged
-        // Use structure-based detection to match the main linting path (since uses_document_structure() returns true)
-        let structure = crate::utils::document_structure::DocumentStructure::new(content);
-        let warnings = self.check_with_structure(ctx, &structure)?;
+        let warnings = self.check(ctx)?;
         if warnings.is_empty() {
             return Ok(content.to_string());
         }
@@ -622,10 +596,6 @@ impl Rule for MD034NoBareUrls {
         self
     }
 
-    fn as_maybe_document_structure(&self) -> Option<&dyn crate::rule::MaybeDocumentStructure> {
-        Some(self)
-    }
-
     fn as_maybe_ast(&self) -> Option<&dyn MaybeAst> {
         Some(self)
     }
@@ -638,17 +608,6 @@ impl Rule for MD034NoBareUrls {
     }
 }
 
-impl crate::utils::document_structure::DocumentStructureExtensions for MD034NoBareUrls {
-    fn has_relevant_elements(
-        &self,
-        ctx: &crate::lint_context::LintContext,
-        _doc_structure: &crate::utils::document_structure::DocumentStructure,
-    ) -> bool {
-        // This rule is only relevant if there might be URLs or emails in the content
-        !self.should_skip(ctx.content)
-    }
-}
-
 impl AstExtensions for MD034NoBareUrls {
     fn has_relevant_ast_elements(&self, ctx: &LintContext, ast: &MarkdownAst) -> bool {
         // Check if AST contains text nodes (where bare URLs would be)
