@@ -93,7 +93,7 @@ impl MD038NoSpaceInCode {
         // Common command patterns - check case-insensitive prefixes
         const COMMAND_PREFIXES: &[&str] = &[
             "git ", "npm ", "cargo ", "docker ", "kubectl ", "pip ", "yarn ", "sudo ", "chmod ", "chown ", "ls ",
-            "cd ", "mkdir ", "rm ", "cp ", "mv ", "cat ", "grep ", "find ", "awk ", "sed ",
+            "cd ", "mkdir ", "rm ", "cp ", "mv ", "cat ", "grep ", "find ", "awk ", "sed ", "rumdl ",
         ];
 
         // Check if content starts with any command (case-insensitive)
@@ -302,10 +302,6 @@ impl Rule for MD038NoSpaceInCode {
         self
     }
 
-    fn as_maybe_document_structure(&self) -> Option<&dyn crate::rule::MaybeDocumentStructure> {
-        Some(self)
-    }
-
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
         let mut map = toml::map::Map::new();
         map.insert(
@@ -345,18 +341,6 @@ impl Rule for MD038NoSpaceInCode {
     }
 }
 
-impl crate::utils::document_structure::DocumentStructureExtensions for MD038NoSpaceInCode {
-    fn has_relevant_elements(
-        &self,
-        ctx: &crate::lint_context::LintContext,
-        _doc_structure: &crate::utils::document_structure::DocumentStructure,
-    ) -> bool {
-        // We now use centralized code spans from LintContext
-        // Quick check without parsing
-        ctx.content.contains('`')
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
