@@ -89,10 +89,10 @@ impl MD041FirstLineHeading {
 
     /// Check if a line is an HTML heading
     fn is_html_heading(line: &str, level: usize) -> bool {
-        if let Ok(Some(captures)) = HTML_HEADING_PATTERN.captures(line.trim()) {
-            if let Some(h_level) = captures.get(1) {
-                return h_level.as_str().parse::<usize>().unwrap_or(0) == level;
-            }
+        if let Ok(Some(captures)) = HTML_HEADING_PATTERN.captures(line.trim())
+            && let Some(h_level) = captures.get(1)
+        {
+            return h_level.as_str().parse::<usize>().unwrap_or(0) == level;
         }
         false
     }
@@ -162,6 +162,9 @@ impl Rule for MD041FirstLineHeading {
             let first_line_content = &first_line_info.content;
             let (start_line, start_col, end_line, end_col) = calculate_line_range(first_line, first_line_content);
 
+            // Detect line ending style for the fix
+            let line_ending = crate::utils::detect_line_ending(content);
+
             warnings.push(LintWarning {
                 rule_name: Some(self.name()),
                 line: start_line,
@@ -172,7 +175,7 @@ impl Rule for MD041FirstLineHeading {
                 severity: Severity::Warning,
                 fix: Some(Fix {
                     range: LineIndex::new(content.to_string()).line_col_to_byte_range_with_length(first_line, 1, 0),
-                    replacement: format!("{} Title\n\n", "#".repeat(self.level)),
+                    replacement: format!("{} Title{}{}", "#".repeat(self.level), line_ending, line_ending),
                 }),
             });
         }
@@ -186,8 +189,11 @@ impl Rule for MD041FirstLineHeading {
             return Ok(content.to_string());
         }
 
+        // Detect the line ending style to use
+        let line_ending = crate::utils::detect_line_ending(&content);
+
         // Re-create context for the potentially fixed content
-        let fixed_ctx = crate::lint_context::LintContext::new(&content);
+        let fixed_ctx = crate::lint_context::LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
 
         // Find the first non-blank line after front matter
         let mut first_content_line_num = None;
@@ -220,7 +226,13 @@ impl Rule for MD041FirstLineHeading {
 
         if !has_any_heading {
             // Add a new title at the beginning
-            result.push_str(&format!("{} Title\n\n{}", "#".repeat(self.level), content));
+            result.push_str(&format!(
+                "{} Title{}{}{}",
+                "#".repeat(self.level),
+                line_ending,
+                line_ending,
+                content
+            ));
         } else if let Some(first_line_idx) = first_content_line_num {
             // Check if first content line is a heading of correct level
             let first_line_info = &fixed_ctx.lines[first_line_idx];
@@ -235,7 +247,7 @@ impl Rule for MD041FirstLineHeading {
                             result.push_str(line);
                         }
                         if i < lines.len() - 1 {
-                            result.push('\n');
+                            result.push_str(line_ending);
                         }
                     }
                 } else {
@@ -249,11 +261,16 @@ impl Rule for MD041FirstLineHeading {
                 // First line is not a heading, add a new title before it
                 for (i, line) in lines.iter().enumerate() {
                     if i == first_line_idx {
-                        result.push_str(&format!("{} Title\n\n", "#".repeat(self.level)));
+                        result.push_str(&format!(
+                            "{} Title{}{}",
+                            "#".repeat(self.level),
+                            line_ending,
+                            line_ending
+                        ));
                     }
                     result.push_str(line);
                     if i < lines.len() - 1 {
-                        result.push('\n');
+                        result.push_str(line_ending);
                     }
                 }
             }
@@ -318,7 +335,7 @@ mod tests {
 
         // First line is a level 1 heading (should pass)
         let content = "# My Document\n\nSome content here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -332,7 +349,7 @@ mod tests {
 
         // First line is a level 2 heading (should fail with level 1 requirement)
         let content = "## My Document\n\nSome content here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 1);
@@ -345,7 +362,7 @@ mod tests {
 
         // First line is plain text (should fail)
         let content = "This is not a heading\n\n# This is a heading";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 1);
@@ -358,7 +375,7 @@ mod tests {
 
         // Empty lines before first heading (should pass - rule skips empty lines)
         let content = "\n\n# My Document\n\nSome content.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -367,7 +384,7 @@ mod tests {
 
         // Empty lines before non-heading content (should fail)
         let content = "\n\nNot a heading\n\nSome content.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 3); // First non-empty line
@@ -380,7 +397,7 @@ mod tests {
 
         // Front matter with title field (should pass)
         let content = "---\ntitle: My Document\nauthor: John Doe\n---\n\nSome content here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -394,7 +411,7 @@ mod tests {
 
         // Front matter without title field (should fail)
         let content = "---\nauthor: John Doe\ndate: 2024-01-01\n---\n\nSome content here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 6); // First content line after front matter
@@ -406,7 +423,7 @@ mod tests {
 
         // Front matter with title field but front_matter_title is false (should fail)
         let content = "---\ntitle: My Document\n---\n\nSome content here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 5); // First content line after front matter
@@ -418,7 +435,7 @@ mod tests {
 
         // HTML comment before heading (should fail)
         let content = "<!-- This is a comment -->\n# My Document\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 1); // HTML comment is the first line
@@ -430,13 +447,13 @@ mod tests {
         let rule = MD041FirstLineHeading::new(2, false);
 
         let content = "## Second Level Heading\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings for correct level 2 heading");
 
         // Wrong level
         let content = "# First Level Heading\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("level 2 heading"));
@@ -448,13 +465,13 @@ mod tests {
 
         // Setext style level 1 heading (should pass)
         let content = "My Document\n===========\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings for setext level 1 heading");
 
         // Setext style level 2 heading (should fail with level 1 requirement)
         let content = "My Document\n-----------\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("level 1 heading"));
@@ -466,7 +483,7 @@ mod tests {
 
         // Empty document (should pass - no warnings)
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings for empty document");
     }
@@ -477,7 +494,7 @@ mod tests {
 
         // Document with only whitespace (should pass - no warnings)
         let content = "   \n\n   \t\n";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings for whitespace-only document");
     }
@@ -488,7 +505,7 @@ mod tests {
 
         // Front matter followed by only whitespace (should pass - no warnings)
         let content = "---\ntitle: Test\n---\n\n   \n\n";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -502,21 +519,21 @@ mod tests {
 
         // TOML front matter with title (should fail - rule only checks for "title:" pattern)
         let content = "+++\ntitle = \"My Document\"\n+++\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("level 1 heading"));
 
         // JSON front matter with title (should fail - doesn't have "title:" pattern, has "\"title\":")
         let content = "{\n\"title\": \"My Document\"\n}\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert!(result[0].message.contains("level 1 heading"));
 
         // YAML front matter with title field (standard case)
         let content = "---\ntitle: My Document\n---\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -525,7 +542,7 @@ mod tests {
 
         // Test mixed format edge case - YAML-style in TOML
         let content = "+++\ntitle: My Document\n+++\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings when title: pattern is found");
     }
@@ -536,7 +553,7 @@ mod tests {
 
         // Malformed front matter with title
         let content = "- --\ntitle: My Document\n- --\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -550,7 +567,7 @@ mod tests {
 
         // Front matter without title field followed by correct heading
         let content = "---\nauthor: John Doe\n---\n\n# My Document\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -564,7 +581,7 @@ mod tests {
 
         // Check that fix suggestion is provided
         let content = "Not a heading\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert!(result[0].fix.is_some());
@@ -580,7 +597,7 @@ mod tests {
         // Complex document with various elements
         let content =
             "---\nauthor: John\n---\n\n<!-- Comment -->\n\n\n# Valid Heading\n\n## Subheading\n\nContent here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 5); // The comment line
@@ -592,7 +609,7 @@ mod tests {
 
         // Heading with special characters and formatting
         let content = "# Welcome to **My** _Document_ with `code`\n\nContent.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -608,7 +625,7 @@ mod tests {
 
             // Correct level
             let content = format!("{} Heading at Level {}\n\nContent.", "#".repeat(level), level);
-            let ctx = LintContext::new(&content);
+            let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert!(
                 result.is_empty(),
@@ -618,7 +635,7 @@ mod tests {
             // Wrong level
             let wrong_level = if level == 1 { 2 } else { 1 };
             let content = format!("{} Wrong Level Heading\n\nContent.", "#".repeat(wrong_level));
-            let ctx = LintContext::new(&content);
+            let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert_eq!(result.len(), 1);
             assert!(result[0].message.contains(&format!("level {level} heading")));
