@@ -81,6 +81,33 @@ impl MD052ReferenceLinkImages {
             return true;
         }
 
+        // Skip programming type annotations like [int, str], [Dict[str, Any]]
+        // These typically have commas and/or nested brackets
+        if text.contains(',') || text.contains('[') || text.contains(']') {
+            // Check if it looks like a type annotation pattern
+            return true;
+        }
+
+        // Note: We don't filter out patterns with backticks because backticks in reference names
+        // are valid markdown syntax, e.g., [`dataclasses.InitVar`] is a valid reference name
+
+        // Skip patterns that look like module/class paths ONLY if they don't have backticks
+        // Backticks indicate intentional code formatting in a reference name
+        // e.g., skip [dataclasses.initvar] but allow [`typing.ClassVar`]
+        if !text.contains('`')
+            && text.contains('.')
+            && !text.contains(' ')
+            && !text.contains('-')
+            && !text.contains('_')
+        {
+            return true;
+        }
+
+        // Note: We don't filter based on word count anymore because legitimate references
+        // can have many words, like "python language reference for import statements"
+        // Word count filtering was causing false positives where valid references were
+        // being incorrectly flagged as unused
+
         // Skip patterns that are just punctuation or operators
         if text.chars().all(|c| !c.is_alphanumeric() && c != ' ') {
             return true;
@@ -207,6 +234,12 @@ impl MD052ReferenceLinkImages {
                 continue;
             }
 
+            // Check for abbreviation syntax (*[ABBR]: Definition) and skip it
+            // Abbreviations are not reference links and should not be tracked
+            if line.trim_start().starts_with("*[") {
+                continue;
+            }
+
             if let Some(cap) = REF_REGEX.captures(line) {
                 // Store references in lowercase for case-insensitive comparison
                 if let Some(reference) = cap.get(1) {
@@ -474,6 +507,12 @@ impl MD052ReferenceLinkImages {
                 continue;
             }
 
+            // Skip abbreviation definitions (*[ABBR]: Definition)
+            // These are not reference links and should not be checked
+            if trimmed_line.starts_with("*[") {
+                continue;
+            }
+
             // Collect positions of brackets that are part of URLs (IPv6, etc.)
             // so we can exclude them from reference checking
             let mut url_bracket_ranges: Vec<(usize, usize)> = Vec::new();
@@ -693,6 +732,33 @@ impl Rule for MD052ReferenceLinkImages {
         let content = ctx.content;
         let mut warnings = Vec::new();
 
+        // OPTIMIZATION: Early exit if no reference-style links/images exist
+        // Check if there are any reference-style links or images in the document
+        let has_reference_links = ctx.links.iter().any(|l| l.is_reference);
+        let has_reference_images = ctx.images.iter().any(|i| i.is_reference);
+
+        // Quick check: If document contains no brackets at all, nothing to check
+        if !content.contains('[') {
+            return Ok(warnings);
+        }
+
+        // Quick check for reference definitions
+        let has_reference_definitions = content.contains("]:");
+
+        // If we have no reference links/images AND no reference definitions,
+        // then check if we might have shortcut references [text]
+        if !has_reference_links && !has_reference_images && !has_reference_definitions {
+            // Only do expensive shortcut checking if we have brackets but no links/images/refs
+            // This handles the case where all brackets are inline links [text](url)
+            let all_brackets_are_inline = ctx.links.iter().all(|l| !l.is_reference)
+                && ctx.images.iter().all(|i| !i.is_reference)
+                && ctx.links.len() + ctx.images.len() > 0;
+
+            if all_brackets_are_inline {
+                return Ok(warnings); // All brackets accounted for as inline links/images
+            }
+        }
+
         // Check if we're in MkDocs mode from the context
         let mkdocs_mode = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
 
