@@ -44,7 +44,28 @@ fn test_config_file_command_with_no_config() {
     assert!(output.status.success());
 
     let stdout = String::from_utf8(output.stdout).unwrap();
-    assert_eq!(stdout.trim(), "No configuration file loaded (--no-config specified)");
+    assert_eq!(
+        stdout.trim(),
+        "No configuration file loaded (--no-config/--isolated specified)"
+    );
+}
+
+#[test]
+fn test_config_file_command_with_isolated() {
+    let rumdl_exe = env!("CARGO_BIN_EXE_rumdl");
+
+    let output = Command::new(rumdl_exe)
+        .args(["config", "file", "--isolated"])
+        .output()
+        .expect("Failed to execute command");
+
+    assert!(output.status.success());
+
+    let stdout = String::from_utf8(output.stdout).unwrap();
+    assert_eq!(
+        stdout.trim(),
+        "No configuration file loaded (--no-config/--isolated specified)"
+    );
 }
 
 #[test]
@@ -111,7 +132,7 @@ disable = ["MD013"]
     let rumdl_path = temp_dir.path().join(".rumdl.toml");
     fs::write(&rumdl_path, rumdl_content).unwrap();
 
-    // Run the config file command (should find both files)
+    // Run the config file command (should find only .rumdl.toml as it has higher precedence)
     let rumdl_exe = env!("CARGO_BIN_EXE_rumdl");
     let output = Command::new(rumdl_exe)
         .args(["config", "file"])
@@ -124,14 +145,12 @@ disable = ["MD013"]
     let stdout = String::from_utf8(output.stdout).unwrap();
     let lines: Vec<&str> = stdout.trim().split('\n').collect();
 
-    // Should have both files listed
-    assert_eq!(lines.len(), 2);
+    // Should only have .rumdl.toml listed (higher precedence than pyproject.toml)
+    assert_eq!(lines.len(), 1);
 
-    let pyproject_absolute = fs::canonicalize(&pyproject_path).unwrap();
     let rumdl_absolute = fs::canonicalize(&rumdl_path).unwrap();
 
-    // Check that both paths are present (order might vary)
-    let output_paths: Vec<String> = lines.iter().map(|s| s.to_string()).collect();
-    assert!(output_paths.contains(&pyproject_absolute.to_string_lossy().to_string()));
-    assert!(output_paths.contains(&rumdl_absolute.to_string_lossy().to_string()));
+    // Check that only .rumdl.toml is present (has higher precedence)
+    let output_path = lines[0];
+    assert_eq!(output_path, rumdl_absolute.to_string_lossy());
 }
