@@ -1,7 +1,7 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::*;
-use rumdl::utils::fix_utils::apply_warning_fixes;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::*;
+use rumdl_lib::utils::fix_utils::apply_warning_fixes;
 use std::time::Instant;
 
 #[test]
@@ -32,7 +32,7 @@ fn test_performance_with_large_content() {
 
     for rule in &rules {
         let start_time = Instant::now();
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
         let check_duration = start_time.elapsed();
 
@@ -105,11 +105,11 @@ fn test_deeply_nested_structures() {
     let rules: Vec<Box<dyn Rule>> = vec![
         Box::new(MD027MultipleSpacesBlockquote),
         Box::new(MD007ULIndent::new(2)),
-        Box::new(MD005ListIndent),
+        Box::new(MD005ListIndent::default()),
     ];
 
     for rule in &rules {
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
         let start_time = Instant::now();
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
@@ -148,7 +148,7 @@ fn test_many_small_issues() {
     }
 
     let rule = MD009TrailingSpaces::default();
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let start_time = Instant::now();
     let warnings = rule.check(&ctx).expect("Rule check should succeed");
@@ -204,9 +204,9 @@ fn test_many_small_issues() {
 fn test_mixed_rule_performance() {
     // Test performance when multiple rules process the same content
     let content = r#"
-# Test Document  
+# Test Document
 
-## Section 1  
+## Section 1
 (https://example.com)[reversed link]
 
 ```
@@ -214,10 +214,10 @@ code without language
 ```
 
 ## Section 2
-- Item 1  
-- Item 2  
+- Item 1
+- Item 2
 
-More content  
+More content
 "#;
 
     let rules: Vec<Box<dyn Rule>> = vec![
@@ -230,7 +230,7 @@ More content
 
     // Test each rule individually first
     for rule in &rules {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
         let start_time = Instant::now();
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
@@ -258,7 +258,7 @@ More content
     }
 
     // Test all rules together (simulate full lint)
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let start_time = Instant::now();
 
     let mut all_warnings = Vec::new();
