@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::*;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::*;
 /// Regression prevention test suite for CLI/LSP consistency patterns
 ///
 /// This test suite guards against reintroducing the exact patterns that were
 /// systematically fixed to achieve 100% CLI/LSP parity. Each test validates
 /// that fixes continue to work correctly and consistently across both methods.
-use rumdl::utils::fix_utils::{apply_warning_fixes, validate_fix_range, warning_fix_to_edit};
+use rumdl_lib::utils::fix_utils::{apply_warning_fixes, validate_fix_range, warning_fix_to_edit};
 
 /// Test Pattern 1: Empty byte ranges (most common regression)
 ///
@@ -36,7 +36,7 @@ fn test_pattern_1_empty_byte_ranges_prevention() {
             Box::new(MD041FirstLineHeading::new(1, false)) as Box<dyn Rule>,
         ),
         // MD042: Should calculate proper length for link replacement
-        ("[](empty-link)", Box::new(MD042NoEmptyLinks) as Box<dyn Rule>),
+        ("[](empty-link)", Box::new(MD042NoEmptyLinks::new()) as Box<dyn Rule>),
         // MD045: Should use regex capture group for URL
         ("![](no-alt-text.jpg)", Box::new(MD045NoAltText::new()) as Box<dyn Rule>),
         // MD047: Should handle trailing newline logic properly
@@ -48,13 +48,13 @@ fn test_pattern_1_empty_byte_ranges_prevention() {
         (
             "```\ncode\n~~~",
             Box::new(MD048CodeFenceStyle::new(
-                rumdl::rules::code_fence_utils::CodeFenceStyle::Backtick,
+                rumdl_lib::rules::code_fence_utils::CodeFenceStyle::Backtick,
             )) as Box<dyn Rule>,
         ),
     ];
 
     for (content, rule) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
 
         for warning in &warnings {
@@ -131,7 +131,7 @@ fn test_pattern_2_content_duplication_prevention() {
     ];
 
     for (content, rule) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
 
         // Apply fixes using both CLI and LSP methods
@@ -191,7 +191,7 @@ fn test_pattern_3_missing_lsp_implementations_prevention() {
     ];
 
     for (content, rule) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).expect("Rule check should succeed");
 
         // Critical regression test: Every warning should have a valid fix
@@ -231,11 +231,11 @@ fn test_byte_range_boundaries() {
         Box::new(MD031BlanksAroundFences::default()),
         Box::new(MD032BlanksAroundLists::strict()),
         Box::new(MD041FirstLineHeading::new(1, false)),
-        Box::new(MD042NoEmptyLinks),
+        Box::new(MD042NoEmptyLinks::new()),
         Box::new(MD045NoAltText::new()),
         Box::new(MD047SingleTrailingNewline),
         Box::new(MD048CodeFenceStyle::new(
-            rumdl::rules::code_fence_utils::CodeFenceStyle::Backtick,
+            rumdl_lib::rules::code_fence_utils::CodeFenceStyle::Backtick,
         )),
         Box::new(MD053LinkImageReferenceDefinitions::default()),
         Box::new(MD055TablePipeStyle::new("consistent".to_string())),
@@ -257,7 +257,7 @@ fn test_byte_range_boundaries() {
         let content_len = content_bytes.len();
 
         for rule in &rules {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let warnings = rule.check(&ctx).expect("Rule check should succeed");
 
             for warning in &warnings {
@@ -306,7 +306,7 @@ fn test_fix_application_idempotency() {
         Box::new(MD021NoMultipleSpaceClosedAtx::new()),
         Box::new(MD022BlanksAroundHeadings::new()),
         Box::new(MD029OrderedListPrefix::new(ListStyle::Ordered)),
-        Box::new(MD042NoEmptyLinks),
+        Box::new(MD042NoEmptyLinks::new()),
     ];
 
     let test_contents = vec![
@@ -319,13 +319,13 @@ fn test_fix_application_idempotency() {
 
     for content in test_contents {
         for rule in &rules {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
             // First application
             let first_fix = rule.fix(&ctx).expect("First fix should succeed");
 
             // Second application on already-fixed content
-            let ctx2 = LintContext::new(&first_fix);
+            let ctx2 = LintContext::new(&first_fix, rumdl_lib::config::MarkdownFlavor::Standard);
             let second_fix = rule.fix(&ctx2).expect("Second fix should succeed");
 
             // Critical regression test: Should be idempotent
@@ -353,7 +353,7 @@ fn test_warning_fix_quality() {
         Box::new(MD021NoMultipleSpaceClosedAtx::new()),
         Box::new(MD022BlanksAroundHeadings::new()),
         Box::new(MD029OrderedListPrefix::new(ListStyle::Ordered)),
-        Box::new(MD042NoEmptyLinks),
+        Box::new(MD042NoEmptyLinks::new()),
         Box::new(MD047SingleTrailingNewline),
     ];
 
@@ -369,7 +369,7 @@ fn test_warning_fix_quality() {
 
     for content in problematic_contents {
         for rule in &rules {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let initial_warnings = rule.check(&ctx).expect("Initial check should succeed");
 
             if !initial_warnings.is_empty() {
@@ -377,7 +377,7 @@ fn test_warning_fix_quality() {
                 let fixed_content = rule.fix(&ctx).expect("Fix should succeed");
 
                 // Check the fixed content
-                let fixed_ctx = LintContext::new(&fixed_content);
+                let fixed_ctx = LintContext::new(&fixed_content, rumdl_lib::config::MarkdownFlavor::Standard);
                 let remaining_warnings = rule.check(&fixed_ctx).expect("Fixed content check should succeed");
 
                 // Critical regression test: Fix should resolve all issues of this rule type
