@@ -1,31 +1,31 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD002FirstHeadingH1;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD002FirstHeadingH1;
 
 #[test]
 fn test_custom_level() {
     let rule = MD002FirstHeadingH1::new(2);
     let content = "## Heading\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_invalid_first_heading() {
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Heading\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 }
 
 #[test]
 fn test_no_headings() {
     let rule = MD002FirstHeadingH1::default();
     let content = "This is a paragraph\nAnother paragraph";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -34,56 +34,60 @@ fn test_no_headings() {
 fn test_only_one_heading() {
     let rule = MD002FirstHeadingH1::default();
     let content = "# Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_closed_atx_heading() {
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Heading ##\n### Subheading ###";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Heading #\n### Subheading ###");
+    assert_eq!(fixed, content); // No fix needed
 }
 
 #[test]
 fn test_fix_first_heading() {
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Heading\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
-    assert_eq!(result, "# Heading\n### Subheading");
+    assert_eq!(result, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_fix_closed_atx_heading() {
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Heading ##\n### Subheading ###";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
-    assert_eq!(result, "# Heading #\n### Subheading ###");
+    assert_eq!(result, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_mixed_heading_styles() {
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Heading\n### Subheading ###\n#### Another heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
-    assert_eq!(result, "# Heading\n### Subheading ###\n#### Another heading");
+    assert_eq!(result, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_indented_first_heading() {
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "  ## Heading\n# Subheading";
     println!("Input: '{}'", content.replace("\n", "\\n"));
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     println!("Output: '{}'", result.replace("\n", "\\n"));
     println!(
@@ -104,43 +108,44 @@ fn test_indented_first_heading() {
     }
     println!();
 
-    assert_eq!(result, "  # Heading\n# Subheading");
+    assert_eq!(result, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_setext_heading() {
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "Heading\n-------\n\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "Heading\n=======\n\n### Subheading");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_with_front_matter() {
+    // With markdownlint compatibility, MD002 doesn't trigger when heading is immediately after front matter
     let rule = MD002FirstHeadingH1::default();
     let content = "---\ntitle: Test\n---\n## Heading\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 4);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings after front matter
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "---\ntitle: Test\n---\n# Heading\n### Subheading");
+    assert_eq!(fixed, content); // No fix needed
 }
 
 #[test]
 fn test_setext_with_front_matter() {
+    // MD002 doesn't trigger when heading is the first non-empty line after front matter
+    // This matches the behavior where MD002 focuses on the first heading regardless of blank lines
     let rule = MD002FirstHeadingH1::default();
     let content = "---\ntitle: Test\n---\n\nHeading\n-------\n\n### Subheading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 5);
+    assert_eq!(result.len(), 0); // Doesn't trigger - first heading is h2 but on first content line
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "---\ntitle: Test\n---\n\nHeading\n=======\n\n### Subheading");
+    assert_eq!(fixed, content); // No fix applied
 }
 
 // Comprehensive test cases as requested
@@ -150,52 +155,45 @@ fn test_document_starting_with_h1() {
     // Test case 1: Document starting with H1 (should pass)
     let rule = MD002FirstHeadingH1::default();
     let content = "# Document Title\n\nSome content here.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_document_starting_with_h2() {
-    // Test case 2: Document starting with H2 (should fail)
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "## Introduction\n\nSome content here.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].message, "First heading should be level 1, found level 2");
-    assert_eq!(result[0].line, 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 
     // Test fix
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Introduction\n\nSome content here.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_document_starting_with_h3_to_h6() {
-    // Test case 3: Document starting with H3, H4, H5, H6 (should fail)
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let test_cases = vec![
-        ("### Section", 3, "# Section"),
-        ("#### Subsection", 4, "# Subsection"),
-        ("##### Detail", 5, "# Detail"),
-        ("###### Minute", 6, "# Minute"),
+        ("### Section", 3),
+        ("#### Subsection", 4),
+        ("##### Detail", 5),
+        ("###### Minute", 6),
     ];
 
-    for (input_heading, level, expected_fix) in test_cases {
+    for (input_heading, _level) in test_cases {
         let rule = MD002FirstHeadingH1::default();
         let content = format!("{input_heading}\n\nSome content.");
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(
-            result[0].message,
-            format!("First heading should be level 1, found level {level}")
-        );
-        assert_eq!(result[0].line, 1);
+        assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 
         // Test fix
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, format!("{expected_fix}\n\nSome content."));
+        assert_eq!(fixed, content); // No fix for first-line headings
     }
 }
 
@@ -204,7 +202,7 @@ fn test_document_with_no_headings_comprehensive() {
     // Test case 4: Document with no headings (should pass)
     let rule = MD002FirstHeadingH1::default();
     let content = "This is a paragraph.\n\nAnother paragraph here.\n\n- List item\n- Another item";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
@@ -218,7 +216,7 @@ fn test_document_with_content_before_first_heading() {
     // Test case 5: Document with content before first heading
     let rule = MD002FirstHeadingH1::default();
     let content = "Some introductory text.\n\nMore introduction.\n\n## First Heading\n\nContent here.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "First heading should be level 1, found level 2");
@@ -237,7 +235,7 @@ fn test_document_starting_with_html_heading() {
     // Test case 6: Document starting with HTML heading
     let rule = MD002FirstHeadingH1::default();
     let content = "<h2>HTML Heading</h2>\n\n## Markdown Heading\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "First heading should be level 1, found level 2");
@@ -253,7 +251,7 @@ fn test_setext_style_h1() {
     // Test case 7: Setext style H1 (==== underline)
     let rule = MD002FirstHeadingH1::default();
     let content = "Document Title\n==============\n\nSome content.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
@@ -264,18 +262,16 @@ fn test_setext_style_h1() {
 
 #[test]
 fn test_setext_style_h2() {
-    // Test case 8: Setext style H2 (---- underline)
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     let rule = MD002FirstHeadingH1::default();
     let content = "Document Title\n--------------\n\nSome content.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].message, "First heading should be level 1, found level 2");
-    assert_eq!(result[0].line, 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 
-    // Test fix (convert to Setext H1)
+    // Test fix
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "Document Title\n=======\n\nSome content.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
@@ -285,31 +281,30 @@ fn test_configuration_for_level_parameter() {
 
     // H2 as first heading should pass
     let content = "## Introduction\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
-    // H1 as first heading should fail
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
+    // H1 as first heading
     let content = "# Main Title\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].message, "First heading should be level 2, found level 1");
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 
     // Test fix
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "## Main Title\n\nContent.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 
-    // H3 as first heading should also fail
+    // H3 as first heading
     let content = "### Section\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].message, "First heading should be level 2, found level 3");
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
 
     // Test fix
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "## Section\n\nContent.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
@@ -317,7 +312,7 @@ fn test_empty_document() {
     // Test case 10: Empty document
     let rule = MD002FirstHeadingH1::default();
     let content = "";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
@@ -331,20 +326,20 @@ fn test_various_edge_cases() {
     // Test with only whitespace
     let rule = MD002FirstHeadingH1::default();
     let content = "   \n   \n   ";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 
     // Test with code blocks containing headings
     let content = "```\n# Not a heading\n```\n\n## First Real Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 5);
 
     // Test with block quotes containing headings
     let content = "> # Quoted heading\n\n### First Real Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 3);
@@ -354,23 +349,24 @@ fn test_various_edge_cases() {
 fn test_fix_preserves_heading_style() {
     let rule = MD002FirstHeadingH1::default();
 
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     // Test closed ATX style preservation
     let content = "### Heading ###\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Heading #\n\nContent.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 
     // Test regular ATX style preservation
     let content = "### Heading\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Heading\n\nContent.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 
     // Test Setext style preservation
     let content = "Heading\n-------\n\nContent.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "Heading\n=======\n\nContent.");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
@@ -379,14 +375,14 @@ fn test_mixed_content_types() {
 
     // Test with lists before heading
     let content = "- Item 1\n- Item 2\n\n### First Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 4);
 
     // Test with tables before heading
     let content = "| Col1 | Col2 |\n|------|------|\n| A    | B    |\n\n## First Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 5);
@@ -404,7 +400,7 @@ fn test_html_headings_comprehensive() {
     ];
 
     for (content, should_pass, expected_line) in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         if should_pass {
             assert!(result.is_empty(), "Expected no errors for content: {content}");
@@ -432,15 +428,14 @@ fn test_setext_variations() {
         (many_dashes.as_str(), false), // Many -
     ];
 
-    for (content, is_h1) in test_cases {
-        let ctx = LintContext::new(content);
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
+    for (content, _is_h1) in test_cases {
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        if is_h1 {
-            assert!(result.is_empty(), "Expected H1 for content: {content}");
-        } else {
-            assert_eq!(result.len(), 1, "Expected error for H2 content: {content}");
-            assert_eq!(result[0].message, "First heading should be level 1, found level 2");
-        }
+        assert!(
+            result.is_empty(),
+            "MD002 should not trigger for first-line heading: {content}"
+        );
     }
 }
 
@@ -448,39 +443,38 @@ fn test_setext_variations() {
 fn test_complex_fix_scenarios() {
     let rule = MD002FirstHeadingH1::default();
 
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     // Test fix with multiple headings of different styles
     let content = "### First Heading ###\n\nSecond Heading\n--------------\n\n##### Third Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(
-        fixed,
-        "# First Heading #\n\nSecond Heading\n--------------\n\n##### Third Heading"
-    );
+    assert_eq!(fixed, content); // No fix for first-line headings
 
     // Test fix with deeply indented heading
     let content = "        #### Deeply Indented";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "        # Deeply Indented");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_edge_cases_with_special_characters() {
     let rule = MD002FirstHeadingH1::default();
 
+    // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
     // Test heading with special characters
     let content = "## Heading with #hashtag and *emphasis*";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Heading with #hashtag and *emphasis*");
+    assert_eq!(fixed, content); // No fix for first-line headings
 
     // Test heading with emoji
     let content = "### 🚀 Rocket Launch";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# 🚀 Rocket Launch");
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
@@ -492,23 +486,19 @@ fn test_custom_level_configurations() {
         // Test that the configured level passes
         let hashes = "#".repeat(level as usize);
         let content = format!("{hashes} Heading at level {level}");
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
             "Level {level} heading should pass for rule configured with level {level}"
         );
 
-        // Test that other levels fail
+        // With markdownlint compatibility, MD002 doesn't trigger for first-line headings
         if level != 1 {
             let content = "# Level 1 Heading";
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
-            assert_eq!(result.len(), 1);
-            assert_eq!(
-                result[0].message,
-                format!("First heading should be level {level}, found level 1")
-            );
+            assert_eq!(result.len(), 0); // MD002 doesn't trigger for first-line headings
         }
     }
 }
@@ -519,35 +509,31 @@ fn test_whitespace_only_lines() {
 
     // Test document with only whitespace lines before heading
     let content = "   \n\t\n  \t  \n\n## First Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
-    assert_eq!(result[0].line, 5);
+    assert_eq!(result.len(), 0); // MD002 doesn't trigger - first non-empty line is a heading
 }
 
 #[test]
 fn test_fix_preserves_trailing_content() {
     let rule = MD002FirstHeadingH1::default();
 
-    // Test that fix preserves all content after the first heading
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let content = "## Wrong Level\n\nParagraph 1\n\n### Subheading\n\nParagraph 2\n\n```\nCode block\n```\n\nEnd.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(
-        fixed,
-        "# Wrong Level\n\nParagraph 1\n\n### Subheading\n\nParagraph 2\n\n```\nCode block\n```\n\nEnd."
-    );
+    assert_eq!(fixed, content); // No fix for first-line headings
 }
 
 #[test]
 fn test_line_ending_preservation() {
     let rule = MD002FirstHeadingH1::default();
 
-    // Test that fix preserves line endings
+    // With markdownlint compatibility, MD002 doesn't fix first-line headings
     let content = "## Heading\nContent";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "# Heading\nContent");
+    assert_eq!(fixed, content); // No fix for first-line headings
 
     // No trailing newline should remain absent
     assert!(!fixed.ends_with('\n'));
@@ -559,7 +545,7 @@ fn test_fix_error_column_positions() {
 
     // Test that error positions are correct
     let content = "Some text\n\n  ### Indented Heading";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 3);
