@@ -1,11 +1,11 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::{MD004UnorderedListStyle, md004_unordered_list_style::UnorderedListStyle};
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::{MD004UnorderedListStyle, md004_unordered_list_style::UnorderedListStyle};
 
 #[test]
 fn test_check_consistent_valid() {
     let content = "* Item 1\n* Item 2\n  * Nested item";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert!(warnings.is_empty());
@@ -14,7 +14,7 @@ fn test_check_consistent_valid() {
 #[test]
 fn test_check_consistent_invalid() {
     let content = "* Item 1\n- Item 2\n  + Nested item";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2);
@@ -23,7 +23,7 @@ fn test_check_consistent_invalid() {
 #[test]
 fn test_check_specific_style_valid() {
     let content = "- Item 1\n- Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
     let warnings = rule.check(&ctx).unwrap();
     assert!(warnings.is_empty());
@@ -32,7 +32,7 @@ fn test_check_specific_style_valid() {
 #[test]
 fn test_check_specific_style_invalid() {
     let content = "* Item 1\n- Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 1);
@@ -41,7 +41,7 @@ fn test_check_specific_style_invalid() {
 #[test]
 fn test_fix_consistent() {
     let content = "* Item 1\n- Item 2\n+ Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "* Item 1\n* Item 2\n* Item 3");
@@ -50,7 +50,7 @@ fn test_fix_consistent() {
 #[test]
 fn test_fix_specific_style() {
     let content = "* Item 1\n- Item 2\n+ Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "* Item 1\n* Item 2\n* Item 3");
@@ -59,7 +59,7 @@ fn test_fix_specific_style() {
 #[test]
 fn test_fix_with_indentation() {
     let content = "  * Item 1\n    - Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "  * Item 1\n    * Item 2");
@@ -68,7 +68,7 @@ fn test_fix_with_indentation() {
 #[test]
 fn test_check_skip_code_blocks() {
     let content = "```\n* Item 1\n- Item 2\n```\n* Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert!(warnings.is_empty());
@@ -77,7 +77,7 @@ fn test_check_skip_code_blocks() {
 #[test]
 fn test_check_skip_front_matter() {
     let content = "---\ntitle: Test\n---\n* Item 1\n- Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 1);
@@ -86,7 +86,7 @@ fn test_check_skip_front_matter() {
 #[test]
 fn test_fix_skip_code_blocks() {
     let content = "```\n* Item 1\n- Item 2\n```\n* Item 3\n- Item 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "```\n* Item 1\n- Item 2\n```\n* Item 3\n* Item 4");
@@ -95,7 +95,7 @@ fn test_fix_skip_code_blocks() {
 #[test]
 fn test_fix_skip_front_matter() {
     let content = "---\ntitle: Test\n---\n* Item 1\n- Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "---\ntitle: Test\n---\n* Item 1\n* Item 2");
@@ -104,7 +104,7 @@ fn test_fix_skip_front_matter() {
 #[test]
 fn test_check_mixed_indentation() {
     let content = "* Item 1\n  - Sub Item 1\n* Item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
 
@@ -115,7 +115,7 @@ fn test_check_mixed_indentation() {
 #[test]
 fn test_check_consistent_first_marker_plus() {
     let content = "+ Item 1\n* Item 2\n- Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2);
@@ -124,7 +124,7 @@ fn test_check_consistent_first_marker_plus() {
 #[test]
 fn test_check_consistent_first_marker_dash() {
     let content = "- Item 1\n* Item 2\n+ Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2);
@@ -133,7 +133,7 @@ fn test_check_consistent_first_marker_dash() {
 #[test]
 fn test_fix_consistent_first_marker_plus() {
     let content = "+ Item 1\n* Item 2\n- Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "+ Item 1\n+ Item 2\n+ Item 3");
@@ -142,7 +142,7 @@ fn test_fix_consistent_first_marker_plus() {
 #[test]
 fn test_fix_consistent_first_marker_dash() {
     let content = "- Item 1\n* Item 2\n+ Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "- Item 1\n- Item 2\n- Item 3");
@@ -151,7 +151,7 @@ fn test_fix_consistent_first_marker_dash() {
 #[test]
 fn test_empty_content() {
     let content = "";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert!(warnings.is_empty());
@@ -160,7 +160,7 @@ fn test_empty_content() {
 #[test]
 fn test_no_list_items() {
     let content = "# Heading\nSome text";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert!(warnings.is_empty());
@@ -168,7 +168,10 @@ fn test_no_list_items() {
 
 #[test]
 fn test_md004_asterisk_style() {
-    let ctx = LintContext::new("- Item 1\n+ Item 2\n  - Nested 1\n  + Nested 2\n* Item 3");
+    let ctx = LintContext::new(
+        "- Item 1\n+ Item 2\n  - Nested 1\n  + Nested 2\n* Item 3",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 4); // All non-asterisk markers are flagged
@@ -178,7 +181,10 @@ fn test_md004_asterisk_style() {
 
 #[test]
 fn test_md004_plus_style() {
-    let ctx = LintContext::new("- Item 1\n* Item 2\n  - Nested 1\n  * Nested 2\n+ Item 3");
+    let ctx = LintContext::new(
+        "- Item 1\n* Item 2\n  - Nested 1\n  * Nested 2\n+ Item 3",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Plus);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 4); // All non-plus markers are flagged
@@ -188,7 +194,10 @@ fn test_md004_plus_style() {
 
 #[test]
 fn test_md004_dash_style() {
-    let ctx = LintContext::new("* Item 1\n+ Item 2\n  * Nested 1\n  + Nested 2\n- Item 3");
+    let ctx = LintContext::new(
+        "* Item 1\n+ Item 2\n  * Nested 1\n  + Nested 2\n- Item 3",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 4); // All non-dash markers are flagged
@@ -198,7 +207,10 @@ fn test_md004_dash_style() {
 
 #[test]
 fn test_md004_deeply_nested() {
-    let ctx = LintContext::new("* Level 1\n  + Level 2\n    - Level 3\n      + Level 4\n  * Back to 2\n* Level 1\n");
+    let ctx = LintContext::new(
+        "* Level 1\n  + Level 2\n    - Level 3\n      + Level 4\n  * Back to 2\n* Level 1\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     // Flags mixed markers (+ and - don't match the first marker *)
@@ -212,7 +224,10 @@ fn test_md004_deeply_nested() {
 
 #[test]
 fn test_md004_mixed_content() {
-    let ctx = LintContext::new("# Heading\n\n* Item 1\n  Some text\n  + Nested with text\n    More text\n* Item 2\n");
+    let ctx = LintContext::new(
+        "# Heading\n\n* Item 1\n  Some text\n  + Nested with text\n    More text\n* Item 2\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     // Flags the + marker that doesn't match the first marker *
@@ -226,7 +241,7 @@ fn test_md004_mixed_content() {
 
 #[test]
 fn test_md004_empty_content() {
-    let ctx = LintContext::new("");
+    let ctx = LintContext::new("", rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
@@ -236,7 +251,10 @@ fn test_md004_empty_content() {
 
 #[test]
 fn test_md004_no_lists() {
-    let ctx = LintContext::new("# Heading\n\nSome text\nMore text");
+    let ctx = LintContext::new(
+        "# Heading\n\nSome text\nMore text",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Heading\n\nSome text\nMore text");
@@ -244,7 +262,10 @@ fn test_md004_no_lists() {
 
 #[test]
 fn test_md004_code_blocks() {
-    let ctx = LintContext::new("* Item 1\n```\n* Not a list\n+ Also not a list\n```\n* Item 2\n");
+    let ctx = LintContext::new(
+        "* Item 1\n```\n* Not a list\n+ Also not a list\n```\n* Item 2\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
@@ -254,7 +275,10 @@ fn test_md004_code_blocks() {
 
 #[test]
 fn test_md004_blockquotes() {
-    let ctx = LintContext::new("* Item 1\n> * Quoted item\n> + Another quoted item\n* Item 2\n");
+    let ctx = LintContext::new(
+        "* Item 1\n> * Quoted item\n> + Another quoted item\n* Item 2\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Should flag the + marker that doesn't match asterisk style
@@ -264,7 +288,10 @@ fn test_md004_blockquotes() {
 
 #[test]
 fn test_md004_list_continuations() {
-    let ctx = LintContext::new("* Item 1\n  Continuation 1\n  + Nested item\n    Continuation 2\n* Item 2\n");
+    let ctx = LintContext::new(
+        "* Item 1\n  Continuation 1\n  + Nested item\n    Continuation 2\n* Item 2\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     // Flags the + marker that doesn't match the first marker *
@@ -278,7 +305,10 @@ fn test_md004_list_continuations() {
 
 #[test]
 fn test_md004_mixed_ordered_unordered() {
-    let ctx = LintContext::new("1. Ordered item\n   * Unordered sub-item\n   + Another sub-item\n2. Ordered item\n");
+    let ctx = LintContext::new(
+        "1. Ordered item\n   * Unordered sub-item\n   + Another sub-item\n2. Ordered item\n",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
@@ -292,7 +322,7 @@ fn test_md004_mixed_ordered_unordered() {
 #[test]
 fn test_complex_list_patterns() {
     let content = "* Level 1 item 1\n  * Level 2 item 1\n    * Level 3 item 1\n  * Level 2 item 2\n* Level 1 item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(
@@ -307,7 +337,7 @@ fn test_lists_in_code_blocks() {
     let content =
         "* Valid list item\n\n```\n* This is in a code block\n- Also in code block\n```\n\n* Another valid item";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0); // No warnings, code blocks ignored
@@ -316,7 +346,7 @@ fn test_lists_in_code_blocks() {
     let content = "* Valid list item\n\n```markdown\n* This is in a code block\n- Also in code block\n```\n\n* Another valid item";
 
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 }
@@ -325,7 +355,7 @@ fn test_lists_in_code_blocks() {
 fn test_nested_list_complexity() {
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let content = "* Item 1\n  - Item 2\n    + Item 3\n  - Item 5\n* Item 6\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Flags mixed markers (- and + don't match the first marker *)
     assert_eq!(result.len(), 3); // - on line 2, + on line 3, - on line 4
@@ -339,7 +369,7 @@ fn test_indentation_handling() {
     let content = "* Level 1\n    * Indented with 4 spaces\n  * Indented with 2 spaces";
 
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0); // Should handle different indentation levels
 
@@ -347,7 +377,7 @@ fn test_indentation_handling() {
     let content = "* Actual list item\nText with * asterisk that's not a list\n  * Indented list item";
 
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0); // Asterisk in middle of line isn't a list marker
 }
@@ -355,7 +385,7 @@ fn test_indentation_handling() {
 #[test]
 fn test_fix_list_markers() {
     let content = "* First item\n* Second item\n* Third item";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "* First item\n* Second item\n* Third item");
@@ -404,12 +434,12 @@ fn test_performance_md004() {
     // Measure performance
     let start = std::time::Instant::now();
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let _result = rule.check(&ctx).unwrap();
     let _check_duration = start.elapsed();
 
     let start = std::time::Instant::now();
-    let fixed_ctx = LintContext::new(&content);
+    let fixed_ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let _ = rule.fix(&fixed_ctx).unwrap();
     let _fix_duration = start.elapsed();
 
@@ -421,7 +451,7 @@ fn test_performance_md004() {
 fn test_configuration_asterisk_style() {
     // Test configuration with asterisk style
     let content = "- Item 1\n+ Item 2\n* Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // - and + don't match asterisk
@@ -433,7 +463,7 @@ fn test_configuration_asterisk_style() {
 fn test_configuration_dash_style() {
     // Test configuration with dash style
     let content = "* Item 1\n+ Item 2\n- Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // * and + don't match dash
@@ -445,7 +475,7 @@ fn test_configuration_dash_style() {
 fn test_configuration_plus_style() {
     // Test configuration with plus style
     let content = "* Item 1\n- Item 2\n+ Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Plus);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // * and - don't match plus
@@ -457,7 +487,7 @@ fn test_configuration_plus_style() {
 fn test_configuration_consistent_style() {
     // Test configuration with consistent style
     let content = "* Item 1\n- Item 2\n* Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 1); // - doesn't match first marker *
@@ -468,7 +498,7 @@ fn test_configuration_consistent_style() {
 fn test_sublist_style_matching() {
     // Test that sublists must match the configured style
     let content = "* Parent 1\n  - Child 1\n  + Child 2\n* Parent 2\n  * Child 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // - and + in sublists don't match asterisk
@@ -481,7 +511,7 @@ fn test_sublist_style_matching() {
 fn test_deeply_nested_sublist_style_matching() {
     // Test deeply nested sublists style matching
     let content = "* Level 1\n  * Level 2\n    - Level 3\n      + Level 4\n        * Level 5";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // - at level 3 and + at level 4 don't match
@@ -497,7 +527,7 @@ fn test_deeply_nested_sublist_style_matching() {
 fn test_lists_after_paragraphs() {
     // Test lists that appear after other content
     let content = "This is a paragraph.\n\n* Item 1\n- Item 2\n\nAnother paragraph.\n\n+ Item 3\n* Item 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // - and + don't match first marker *
@@ -507,7 +537,7 @@ fn test_lists_after_paragraphs() {
 fn test_lists_after_headings() {
     // Test lists that appear after headings
     let content = "# Heading 1\n\n- Item 1\n- Item 2\n\n## Heading 2\n\n* Item 3\n+ Item 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // * and + don't match first marker -
@@ -517,7 +547,7 @@ fn test_lists_after_headings() {
 fn test_fix_preserves_list_content() {
     // Test that fix preserves the content after list markers
     let content = "* Item with **bold** text\n- Item with `code` text\n+ Item with [link](url)";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(
@@ -530,7 +560,7 @@ fn test_fix_preserves_list_content() {
 fn test_multiple_lists_in_blockquotes() {
     // Test multiple lists inside blockquotes
     let content = "> * Quoted item 1\n> - Quoted item 2\n>\n> + New list item 1\n> * New list item 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Consistent);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 2); // - and + don't match first marker *
@@ -547,7 +577,7 @@ fn test_nested_blockquotes_with_lists() {
     // Test nested blockquotes with lists
     // TODO: Current implementation doesn't check lists inside blockquotes
     let content = "> * Level 1 quote\n> > - Level 2 quote\n> > + Another level 2";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let warnings = rule.check(&ctx).unwrap();
     assert_eq!(warnings.len(), 0); // Currently doesn't check lists in blockquotes
@@ -558,7 +588,7 @@ fn test_fix_method_comprehensive() {
     // Comprehensive test of fix method with various scenarios
     let content = "# Header\n\n* Item 1\n  - Subitem 1.1\n  + Subitem 1.2\n\n> - Quoted item\n> * Another quoted\n\n```\n* Code block item (should not change)\n- Another code item\n```\n\n* Item 2\n  * Subitem 2.1";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let fixed = rule.fix(&ctx).unwrap();
 
@@ -572,7 +602,7 @@ fn test_check_method_comprehensive() {
     // Comprehensive test of check method with various scenarios
     let content = "* Valid item\n- Invalid item\n  + Invalid nested\n  * Valid nested\n\n> - Invalid quoted\n\n```\n- Ignored in code\n```";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
     let warnings = rule.check(&ctx).unwrap();
 
@@ -597,7 +627,7 @@ mod parity_with_markdownlint {
     fn parity_mixed_markers_no_trailing_newline() {
         let input = "* Item 1\n- Item 2\n+ Item 3";
         let expected = "* Item 1\n* Item 2\n* Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -607,7 +637,7 @@ mod parity_with_markdownlint {
     fn parity_mixed_markers_with_trailing_newline() {
         let input = "* Item 1\n- Item 2\n+ Item 3\n";
         let expected = "* Item 1\n* Item 2\n* Item 3\n";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -617,7 +647,7 @@ mod parity_with_markdownlint {
     fn parity_nested_lists() {
         let input = "* Level 1\n  - Level 2\n    + Level 3\n  - Level 2b\n* Level 1b";
         let expected = "* Level 1\n  * Level 2\n    * Level 3\n  * Level 2b\n* Level 1b";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -627,7 +657,7 @@ mod parity_with_markdownlint {
     fn parity_code_blocks_and_front_matter() {
         let input = "---\ntitle: Test\n---\n* Item 1\n- Item 2\n```\n* Not a list\n- Not a list\n```\n* Item 3\n";
         let expected = "---\ntitle: Test\n---\n* Item 1\n* Item 2\n```\n* Not a list\n- Not a list\n```\n* Item 3\n";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -637,7 +667,7 @@ mod parity_with_markdownlint {
     fn parity_empty_input() {
         let input = "";
         let expected = "";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -647,7 +677,7 @@ mod parity_with_markdownlint {
     fn parity_no_lists() {
         let input = "# Heading\nSome text";
         let expected = "# Heading\nSome text";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -657,7 +687,7 @@ mod parity_with_markdownlint {
     fn parity_single_style_list() {
         let input = "- Item 1\n- Item 2\n- Item 3";
         let expected = "- Item 1\n- Item 2\n- Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Dash);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -667,7 +697,7 @@ mod parity_with_markdownlint {
     fn parity_list_with_blank_lines() {
         let input = "* Item 1\n\n- Item 2\n\n+ Item 3";
         let expected = "* Item 1\n\n* Item 2\n\n* Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -677,7 +707,7 @@ mod parity_with_markdownlint {
     fn parity_blockquote_with_lists() {
         let input = "* Item 1\n> * Quoted item\n> + Another quoted item\n* Item 2";
         let expected = "* Item 1\n> * Quoted item\n> * Another quoted item\n* Item 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -687,7 +717,7 @@ mod parity_with_markdownlint {
     fn parity_single_item_list() {
         let input = "* Only item";
         let expected = "* Only item";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -697,7 +727,7 @@ mod parity_with_markdownlint {
     fn parity_list_with_tabs_for_indentation() {
         let input = "* Item 1\n\t- Nested with tab\n\t\t+ Double tab nested";
         let expected = "* Item 1\n\t* Nested with tab\n\t\t* Double tab nested";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -707,7 +737,7 @@ mod parity_with_markdownlint {
     fn parity_list_with_extra_whitespace_after_marker() {
         let input = "*    Item 1\n-      Item 2\n+   Item 3";
         let expected = "*    Item 1\n*      Item 2\n*   Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD004UnorderedListStyle::new(UnorderedListStyle::Asterisk);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
