@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD027MultipleSpacesBlockquote;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD027MultipleSpacesBlockquote;
 
 #[test]
 fn test_md027_valid() {
     let rule = MD027MultipleSpacesBlockquote;
     let content = "> Quote\n> Another line\n> Third line\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_md027_valid() {
 fn test_md027_invalid() {
     let rule = MD027MultipleSpacesBlockquote;
     let content = ">  Quote\n>   Another line\n>    Third line\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
     assert_eq!(result[0].line, 1);
@@ -27,7 +27,7 @@ fn test_md027_invalid() {
 fn test_md027_mixed() {
     let rule = MD027MultipleSpacesBlockquote;
     let content = "> Quote\n>  Another line\n> Third line\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].line, 2);
@@ -37,7 +37,7 @@ fn test_md027_mixed() {
 fn test_md027_fix() {
     let rule = MD027MultipleSpacesBlockquote;
     let content = ">  Quote\n>   Another line\n>    Third line\n";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "> Quote\n> Another line\n> Third line\n");
 }
