@@ -1,43 +1,43 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::{ListStyle, MD029OrderedListPrefix};
-use rumdl::utils::range_utils::LineIndex;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::{ListStyle, MD029OrderedListPrefix};
+use rumdl_lib::utils::range_utils::LineIndex;
 
 #[test]
 fn test_md029_valid() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::OneOne);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::OneOne);
 
     let content = r#"1. Item 1
 1. Item 2
 1. Item 3"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_md029_ordered_any_valid() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
 
     let content = r#"1. Item 1
 2. Item 2
 3. Item 3"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_md029_ordered_any_invalid() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
 
     let content = r#"1. Item 1
 1. Item 2
 1. Item 3"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 
@@ -48,23 +48,23 @@ fn test_md029_ordered_any_invalid() {
 
 #[test]
 fn test_md029_nested() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::OneOne);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::OneOne);
     let content = r#"1. First item
    1. Nested first
    1. Nested second
 1. Second item"#;
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_md029_fix() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
     let content = r#"1. First item
 3. Second item
 5. Third item"#;
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(result, "1. First item\n2. Second item\n3. Third item");
 }
@@ -83,7 +83,7 @@ fn test_line_index() {
 
 #[test]
 fn test_md029_with_code_blocks() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
 
     let content = r#"1. First step
 ```bash
@@ -98,7 +98,7 @@ more code
 final code
 ```"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -115,7 +115,7 @@ final code
 
 #[test]
 fn test_md029_nested_with_code_blocks() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
 
     let content = r#"1. First step
    ```bash
@@ -132,7 +132,7 @@ fn test_md029_nested_with_code_blocks() {
    ```
 3. Third step"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("Warnings: {result:?}");
     assert!(
@@ -150,7 +150,7 @@ fn test_md029_nested_with_code_blocks() {
 
 #[test]
 fn test_md029_code_blocks_in_nested_lists() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::One);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::One);
 
     let content = r#"1. First item
 
@@ -171,7 +171,7 @@ fn test_md029_code_blocks_in_nested_lists() {
 
    2. Another nested"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let warnings = rule.check(&ctx).unwrap();
 
     // Should handle numbering correctly despite code blocks
@@ -181,7 +181,7 @@ fn test_md029_code_blocks_in_nested_lists() {
 
 #[test]
 fn test_md029_fenced_vs_indented_in_list() {
-    let rule = MD029OrderedListPrefix::new(rumdl::rules::ListStyle::Ordered);
+    let rule = MD029OrderedListPrefix::new(rumdl_lib::rules::ListStyle::Ordered);
 
     let content = r#"1. Item with fenced code:
    ```js
@@ -195,7 +195,7 @@ fn test_md029_fenced_vs_indented_in_list() {
 
 3. Final item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let warnings = rule.check(&ctx).unwrap();
 
     assert!(warnings.is_empty(), "Ordered numbering should be accepted");
@@ -216,15 +216,15 @@ fn test_zero_padded_numbers() {
 02. Second item
 05. Wrong number with padding";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should detect that 05 should be 03
     assert!(!result.is_empty(), "Should detect wrong zero-padded number");
 
     let fixed = rule.fix(&ctx).unwrap();
-    // The fix should correct the sequence
-    assert!(fixed.contains("3. Wrong number") || fixed.contains("03. Wrong number"));
+    // The fix should correct the sequence (removes leading zeros and fixes numbering)
+    assert!(fixed.contains("3. Wrong number with padding"));
 }
 
 #[test]
@@ -236,7 +236,7 @@ fn test_lists_with_inline_html() {
 <div>Some HTML block</div>
 4. Wrong number after HTML";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // HTML should not interfere with numbering detection
@@ -257,7 +257,7 @@ fn test_lists_with_html_comments() {
 <!-- Another comment -->
 4. Wrong number after comments";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Comments should not break list sequences
@@ -276,7 +276,7 @@ fn test_lists_with_mathematical_expressions() {
 2. The result of 1.5 + 2.3 is 3.8
 4. Wrong number with math: 10.5 / 2.1";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Mathematical expressions shouldn't interfere with list numbering
@@ -304,7 +304,7 @@ fn test_deeply_nested_lists() {
           1. Level 6 item
           3. Wrong number at deep level";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should handle deep nesting and detect the wrong number
@@ -329,7 +329,7 @@ fn test_analyze_performance_errors() {
 
     println!("Content:\n{content}");
 
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     println!("Found {} warnings:", result.len());
@@ -354,7 +354,7 @@ fn test_performance_with_many_small_lists() {
         content.push_str(&format!("3. List {i} item 3 (wrong)\n\n")); // Wrong number
     }
 
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let start = std::time::Instant::now();
     let result = rule.check(&ctx).unwrap();
@@ -363,18 +363,11 @@ fn test_performance_with_many_small_lists() {
     // Should complete quickly even with many errors
     assert!(duration.as_millis() < 500, "Should complete within 500ms");
 
-    // Let's be more precise: verify the actual behavior
-    // If the rule is treating all items as one big sequence instead of separate lists,
-    // that would be wrong and needs fixing
-    if result.len() > 100 {
-        println!("CRITICAL: Found {} errors instead of expected 100", result.len());
-        println!("This suggests the rule may be incorrectly grouping separate lists");
-
-        // For now, let's allow this but flag it for investigation
-        assert!(result.len() >= 100, "Should find at least the expected errors");
-    } else {
-        assert_eq!(result.len(), 100, "Should find exactly 2 errors per list * 50 lists");
-    }
+    // Should find at least 100 errors (2 per intended list)
+    assert!(
+        result.len() >= 100,
+        "Should find at least 100 errors (2 per intended list)"
+    );
 }
 
 #[test]
@@ -394,7 +387,7 @@ fn test_lists_with_continuation_paragraphs() {
 
    This item has wrong numbering.";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Continuation paragraphs should not break sequences
@@ -414,7 +407,7 @@ fn test_mixed_indentation_patterns() {
      1. Indented 5 spaces total
   3. Back to 2 spaces - wrong number";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should handle non-standard indentation robustly
@@ -435,7 +428,7 @@ fn test_single_item_edge_cases() {
 
     for (style, content, should_have_error) in test_cases {
         let rule = MD029OrderedListPrefix::new(style.clone());
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         if should_have_error {
@@ -458,12 +451,25 @@ second line of first item
 1. Second item first line
 second line of second item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
-    // Should have warning for second "1." since it should be "2."
-    assert_eq!(result.len(), 1, "No indentation should be treated as continuation");
-    assert!(result[0].message.contains("1 does not match style (expected 2)"));
+    // Should have warnings for:
+    // 1. Lazy continuation on line 2
+    // 2. Wrong number on line 3
+    // 3. Lazy continuation on line 4
+    assert!(
+        result.len() >= 3,
+        "Should detect lazy continuations and wrong numbering"
+    );
+
+    // Check for lazy continuation warnings
+    let lazy_warnings = result.iter().filter(|w| w.rule_name == Some("MD029-style")).count();
+    assert_eq!(lazy_warnings, 2, "Should have 2 lazy continuation warnings");
+
+    // Check for numbering warning
+    let numbering_warnings = result.iter().filter(|w| w.rule_name == Some("MD029")).count();
+    assert_eq!(numbering_warnings, 1, "Should have 1 numbering warning");
 }
 
 #[test]
@@ -476,7 +482,7 @@ fn test_md029_multiline_3_space_indent() {
 1. Second item first line
    second line of second item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should have warning for second "1." since it should be "2."
@@ -494,7 +500,7 @@ fn test_md029_multiline_4_space_indent() {
 1. Second item first line
     second line of second item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should have warning for second "1." since it should be "2."
@@ -512,7 +518,7 @@ fn test_md029_multiline_2_space_indent() {
 1. Second item first line
   second line of second item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // 2 spaces is not enough for ordered list continuation (need 3)
@@ -533,7 +539,7 @@ code block
 2. Second item
    continuation line"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty(), "Code blocks should not break list numbering");
 }
@@ -547,7 +553,7 @@ fn test_md029_fix_multiline_3_space() {
 1. Second item first line
    second line of second item"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let fixed = rule.fix(&ctx).unwrap();
 
     let expected = r#"1. First item first line
@@ -570,7 +576,7 @@ fn test_md029_double_digit_marker_width() {
 11. Eleventh item
      continuation with 5 spaces"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // All items should be part of the same list
@@ -592,7 +598,7 @@ fn test_md029_double_digit_insufficient_indent() {
 11. Eleventh item
     text"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Line 2 has 3 spaces (OK for "9. ")
@@ -622,7 +628,7 @@ fn test_md029_triple_digit_marker_width() {
 101. One hundred first item
      continuation with 5 spaces"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // All items should be part of the same list
@@ -644,7 +650,7 @@ fn test_md029_quadruple_digit_marker_width() {
 1111. Eleven eleven item
       continuation with 6 spaces"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // All items should be part of the same list
@@ -666,7 +672,7 @@ fn test_md029_large_digit_insufficient_indent() {
 1000. Item one thousand
      only 5 spaces (not enough for "1000. " which needs 6)"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // We expect the list to be broken into multiple blocks
@@ -678,6 +684,63 @@ fn test_md029_large_digit_insufficient_indent() {
     assert!(result[2].message.contains("1000 does not match style (expected 1)")); // New list
 }
 
+#[test]
+fn test_md029_lazy_continuation_fix() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    // Test that MD029 fixes numbering (not indentation)
+    // Note: lazy continuation breaks the list, so "1. Second item" starts a new list
+    let content = r#"1. First item
+lazy continuation
+1. Second item
+another lazy line"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let fixed = rule.fix(&ctx).unwrap();
+
+    // MD029 only fixes numbering, not indentation
+    // The lazy continuation doesn't actually break the list in our implementation,
+    // so "1. Second item" should become "2. Second item"
+    let expected = r#"1. First item
+lazy continuation
+2. Second item
+another lazy line"#;
+
+    assert_eq!(fixed, expected, "MD029 should only fix list numbering");
+}
+
+#[test]
+fn test_md029_mixed_lazy_and_proper_continuation() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    let content = r#"1. First item
+lazy line
+   proper continuation
+1. Second item
+  two space indent
+    four space indent"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should detect lazy continuations (0 and 2 space lines)
+    let lazy_warnings = result.iter().filter(|w| w.rule_name == Some("MD029-style")).count();
+    // Note: Only line 2 is detected as lazy continuation because it's within the list block.
+    // Line 5 has 2 spaces but it's after line 4 which starts a new list, so it's not
+    // considered part of the list block and thus not checked for lazy continuation.
+    assert_eq!(lazy_warnings, 1, "Should detect 0-space line as lazy continuation");
+
+    // MD029 fix only fixes list numbering, not indentation
+    let fixed = rule.fix(&ctx).unwrap();
+    // Lazy lines remain unchanged
+    assert!(fixed.contains("\nlazy line"));
+    // The list item numbering is fixed
+    assert!(fixed.contains("1. First item"));
+    assert!(fixed.contains("2. Second item")); // Second item becomes "2." not "1."
+    // Two-space indent line remains unchanged (MD029 doesn't fix indentation)
+    assert!(fixed.contains("  two space indent"));
+}
+
 #[test]
 fn test_md029_simple_insufficient_indent() {
     let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
@@ -687,7 +750,7 @@ fn test_md029_simple_insufficient_indent() {
    not enough spaces
 10. Item ten again"#;
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Line 2 has 3 spaces but needs 4 for "10. "
@@ -701,3 +764,315 @@ fn test_md029_simple_insufficient_indent() {
     assert!(result[0].message.contains("10 does not match style (expected 1)"));
     assert!(result[1].message.contains("10 does not match style (expected 1)"));
 }
+
+#[test]
+fn test_md029_nested_ordered_lists_issue_52() {
+    // Test for GitHub issue #52: nested ordered lists incorrectly treated as continuous sequence
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    // Exact test case from issue #52
+    let content = r#"# Title
+
+1. Top 1
+   1. Sub 1
+   1. Sub 2
+2. Top 2
+   1. Sub 3
+   1. Sub 4"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only flag 2 errors (not 3 as the bug produced):
+    // - Line 5: "1. Sub 2" should be "2. Sub 2"
+    // - Line 8: "1. Sub 4" should be "2. Sub 4"
+    // Line 7: "1. Sub 3" should NOT be flagged (correctly starts new nested sequence)
+    assert_eq!(result.len(), 2, "Should only flag 2 errors after fix");
+
+    // Verify the specific errors - they should be on lines 5 and 8
+    let line_5_error = result.iter().find(|w| w.line == 5);
+    let line_8_error = result.iter().find(|w| w.line == 8);
+
+    assert!(line_5_error.is_some(), "Should have error on line 5");
+    assert!(line_8_error.is_some(), "Should have error on line 8");
+
+    assert!(
+        line_5_error
+            .unwrap()
+            .message
+            .contains("1 does not match style (expected 2)"),
+        "Line 5 should expect 2, got: {}",
+        line_5_error.unwrap().message
+    );
+    assert!(
+        line_8_error
+            .unwrap()
+            .message
+            .contains("1 does not match style (expected 2)"),
+        "Line 8 should expect 2, got: {}",
+        line_8_error.unwrap().message
+    );
+
+    // Test the fix function produces correct output
+    let fixed = rule.fix(&ctx).unwrap();
+    let expected_fixed = r#"# Title
+
+1. Top 1
+   1. Sub 1
+   2. Sub 2
+2. Top 2
+   1. Sub 3
+   2. Sub 4"#;
+
+    assert_eq!(fixed, expected_fixed, "Fix should produce correct nested numbering");
+}
+
+#[test]
+fn test_md029_nested_ordered_lists_bug() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    // Test case from issue #52 - nested ordered lists should restart numbering
+    let content = r#"# Title
+
+1. Top 1
+   1. Sub 1
+   1. Sub 2
+2. Top 2
+   1. Sub 3
+   1. Sub 4"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+
+    // Debug info
+    println!("List blocks found:");
+    for (i, block) in ctx.list_blocks.iter().enumerate() {
+        println!(
+            "  Block {}: lines {}-{}, item_lines: {:?}, is_ordered: {}",
+            i, block.start_line, block.end_line, block.item_lines, block.is_ordered
+        );
+    }
+
+    println!("Line info for list items:");
+    for line_num in 1..=ctx.content.lines().count() {
+        if let Some(line_info) = ctx.line_info(line_num)
+            && let Some(list_item) = &line_info.list_item
+        {
+            println!(
+                "  Line {}: '{}' - marker: '{}', column: {}, ordered: {}",
+                line_num,
+                line_info.content.trim(),
+                list_item.marker,
+                list_item.marker_column,
+                list_item.is_ordered
+            );
+        }
+    }
+
+    let result = rule.check(&ctx).unwrap();
+
+    println!("Found {} warnings:", result.len());
+    for warning in &result {
+        println!("  Line {}: {}", warning.line, warning.message);
+    }
+
+    // Expected behavior: nested ordered lists should restart numbering at each level
+    // So we should NOT get warnings for the nested "1." items
+    // But the current implementation incorrectly treats them as one continuous sequence
+
+    // This test currently fails - documenting the bug
+    // The nested "1. Sub 1", "1. Sub 3" should NOT be flagged as errors
+    // Only the second "1. Sub 2" and "1. Sub 4" should be flagged (should be "2.")
+
+    // Expected warnings:
+    // - Line 5: "1. Sub 2" should be "2. Sub 2"
+    // - Line 8: "1. Sub 4" should be "2. Sub 4"
+
+    // Now the fix is working correctly!
+    // We should get exactly 2 warnings for the second items in each nested sequence
+    assert_eq!(
+        result.len(),
+        2,
+        "Should have exactly 2 warnings for nested sequence numbering"
+    );
+
+    // Check that the correct lines are flagged with the correct expected numbers
+    assert!(
+        result
+            .iter()
+            .any(|w| w.line == 5 && w.message.contains("1 does not match style (expected 2)")),
+        "Line 5 (1. Sub 2) should be flagged as needing to be 2"
+    );
+    assert!(
+        result
+            .iter()
+            .any(|w| w.line == 8 && w.message.contains("1 does not match style (expected 2)")),
+        "Line 8 (1. Sub 4) should be flagged as needing to be 2"
+    );
+
+    // Test the fix function too
+    let fixed = rule.fix(&ctx).unwrap();
+    let expected_fixed = r#"# Title
+
+1. Top 1
+   1. Sub 1
+   2. Sub 2
+2. Top 2
+   1. Sub 3
+   2. Sub 4"#;
+
+    assert_eq!(
+        fixed, expected_fixed,
+        "Fix should correct the nested sequence numbering"
+    );
+}
+
+// Additional edge cases for nested lists to ensure robustness
+
+#[test]
+fn test_md029_triple_nested_ordered_lists() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    let content = r#"1. Level 1 item 1
+   1. Level 2 item 1
+      1. Level 3 item 1
+      2. Level 3 item 2
+   2. Level 2 item 2
+      1. Level 3 item 3
+      1. Level 3 item 4 - wrong
+2. Level 1 item 2
+   1. Level 2 item 3
+      1. Level 3 item 5
+      3. Level 3 item 6 - wrong"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should detect 2 errors: lines 7 and 11 (second items at level 3 under different parents)
+    assert_eq!(result.len(), 2, "Should detect 2 errors in triple-nested structure");
+
+    // Verify specific errors
+    let line_7_error = result.iter().find(|w| w.line == 7);
+    let line_11_error = result.iter().find(|w| w.line == 11);
+
+    assert!(line_7_error.is_some(), "Should have error on line 7");
+    assert!(line_11_error.is_some(), "Should have error on line 11");
+
+    assert!(
+        line_7_error
+            .unwrap()
+            .message
+            .contains("1 does not match style (expected 2)")
+    );
+    assert!(
+        line_11_error
+            .unwrap()
+            .message
+            .contains("3 does not match style (expected 2)")
+    );
+}
+
+#[test]
+fn test_md029_ordered_under_unordered_parents() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    let content = r#"- Unordered parent 1
+  1. Nested ordered 1
+  1. Nested ordered 2 (should be 2)
+- Unordered parent 2
+  1. New sequence starts at 1
+  3. Should be 2
+- Unordered parent 3
+  1. Another sequence starts at 1"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should find 2 errors: second items under each unordered parent
+    assert_eq!(
+        result.len(),
+        2,
+        "Should find 2 errors in ordered lists under unordered parents"
+    );
+
+    // Verify the errors are on the expected lines
+    let has_line_3_error = result.iter().any(|w| w.line == 3 && w.message.contains("expected 2"));
+    let has_line_6_error = result.iter().any(|w| w.line == 6 && w.message.contains("expected 2"));
+
+    assert!(has_line_3_error, "Should have error on line 3");
+    assert!(has_line_6_error, "Should have error on line 6");
+}
+
+#[test]
+fn test_md029_lists_with_code_block_interruptions() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    let content = r#"1. First item
+   ```python
+   code block
+   ```
+2. Second item (should maintain sequence)
+   1. Nested item
+   ```rust
+   more code
+   ```
+   1. Should be 2 after code block"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should find 1 error: the nested "1." that should be "2."
+    assert_eq!(result.len(), 1, "Should find 1 error for nested item after code block");
+    assert!(result[0].message.contains("1 does not match style (expected 2)"));
+}
+
+#[test]
+fn test_md029_mixed_indentation_robustness() {
+    let rule = MD029OrderedListPrefix::new(ListStyle::Ordered);
+
+    // Mix of 2, 3, and 4 space indentation
+    let content = r#"1. Normal item
+  1. 2-space nested (non-standard)
+    1. 4-space nested
+    3. Should be 2
+   1. 3-space nested (back to standard)
+   5. Should be 2"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should handle mixed indentation gracefully and detect numbering errors
+    assert!(
+        !result.is_empty(),
+        "Should detect numbering errors despite mixed indentation"
+    );
+}
+
+#[test]
+fn test_md029_all_styles_with_nesting() {
+    // Test that all ListStyle variants work with nested scenarios without crashing
+    let styles = vec![
+        ListStyle::One,
+        ListStyle::OneOne,
+        ListStyle::Ordered,
+        ListStyle::Ordered0,
+    ];
+
+    let content = r#"1. Top level
+   1. Nested level
+   2. Second nested
+2. Second top
+   1. Another nested"#;
+
+    for style in styles {
+        let rule = MD029OrderedListPrefix::new(style.clone());
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx);
+
+        // Just verify it doesn't crash and produces some result
+        assert!(result.is_ok(), "Style {style:?} should not crash on nested lists");
+
+        // Test that fix works too
+        let fixed = rule.fix(&ctx);
+        assert!(fixed.is_ok(), "Style {style:?} fix should not crash on nested lists");
+    }
+}
