@@ -1,11 +1,11 @@
-use rumdl::rule::Rule;
-use rumdl::rules::MD045NoAltText;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD045NoAltText;
 
 #[test]
 fn test_valid_alt_text() {
     let rule = MD045NoAltText::new();
     let content = "![Alt text](image.png)\n![Another description](path/to/image.jpg)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -14,7 +14,7 @@ fn test_valid_alt_text() {
 fn test_missing_alt_text() {
     let rule = MD045NoAltText::new();
     let content = "![](image.png)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -25,7 +25,7 @@ fn test_missing_alt_text() {
 fn test_empty_alt_text() {
     let rule = MD045NoAltText::new();
     let content = "![ ](image.png)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -36,7 +36,7 @@ fn test_empty_alt_text() {
 fn test_multiple_images() {
     let rule = MD045NoAltText::new();
     let content = "![Alt text](image1.png)\n![](image2.png)\n![ ](image3.png)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -50,7 +50,7 @@ fn test_multiple_images() {
 fn test_complex_urls() {
     let rule = MD045NoAltText::new();
     let content = "![](https://example.com/image.png?param=value#fragment)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -64,7 +64,7 @@ fn test_complex_urls() {
 fn test_mixed_content() {
     let rule = MD045NoAltText::new();
     let content = "# Images\n\nSome text here\n\n![Alt text](image1.png)\n\nMore text\n\n![](image2.png)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -78,7 +78,7 @@ fn test_mixed_content() {
 fn test_inline_images() {
     let rule = MD045NoAltText::new();
     let content = "Text with ![Alt text](inline1.png) and ![](inline2.png) images.";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -92,7 +92,7 @@ fn test_inline_images() {
 fn test_placeholder_clarity() {
     let rule = MD045NoAltText::new();
     let content = "![](screenshot.png)\n![  ](diagram.svg)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Should detect both images with missing alt text");
 
@@ -129,7 +129,7 @@ Another actual image:
 And in inline code: `![](inline.png)` should also be ignored.
 "#;
 
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only detect the two actual images outside code blocks
@@ -154,7 +154,7 @@ And in inline code: `![](inline.png)` should also be ignored.
 fn test_descriptive_filenames() {
     let rule = MD045NoAltText::new();
     let content = "![](user-profile.jpg)\n![](product_screenshot.png)\n![](logo-dark-mode.svg)";
-    let ctx = rumdl::lint_context::LintContext::new(content);
+    let ctx = rumdl_lib::lint_context::LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3);
 
